# SPDX-FileCopyrightText: 2014 Sven Brauch <svenbrauch@gmail.com>
# SPDX-FileCopyrightText: 2024 Jarmo Tiitto <jarmo.tiitto@gmail.com>
# SPDX-License-Identifier: GPL-2.0-or-later

''' KDevelop python debugger (kdevPdb)
        A few points:
        * kdevPdb normally doesn't output anything into stdout or stderr. message()
          and error() are used to output messages, except for fatal errors like
          uncaught exceptions which are printed to stderr.
        * kdevPdb does out-of-band communication via a stream socket using
          the kdevPdbConnection helper module.
'''

import sys
import json
import getopt
import traceback
from pdb import _ModuleTarget, _ScriptTarget, _ZipTarget
from bdb import Breakpoint
import kdevpdbcore
import kdevpdbconn
import kdevpdbvariablesupport

# pylint: disable=C0103, R0903


class kdevPdb(kdevpdbcore.kdevDbgCore, kdevpdbvariablesupport.kdevExprValueMapper):
    def __init__(self, socketpath="/tmp/"):
        kdevpdbcore.kdevDbgCore.__init__(self)
        # Connect to a client.
        self.pdbsrv = kdevpdbconn.kdevPdbConnection()
        self.pdbsrv.dataframes.append(json.dumps({"seq": -1}).encode())
        # Connect to a client.
        self.pdbsrv.establish(socketpath)
        # The command's output is associated with it by the command sequence number.
        # The seqnro begins from the preinit response -1.
        self.command_seqnro = -1
        self.responses = {}
        # The kdevPdb responds with {"seq":-1} once the client has connected
        # and the program is successfully started.
        self.debugger_initialized = False
        self.deleted_breaks = set()
        self.currentbp = 0
        # The user selected active stack-frame.
        self.activeindex = -1
        # Init the variable tracker.
        kdevpdbvariablesupport.kdevExprValueMapper.__init__(self)

    def append_response(self, obj):
        assert isinstance(obj, dict)
        # TODO: Check that the data-frame size does not grow past WARN_TOO_BIG_FRAMESIZE.
        #       We should consider an mechanism to report a such event as an error to the client.
        self.responses.setdefault(self.command_seqnro, []).append(obj)

    def send_response(self):
        '''Send the current response to KDevelop'''
        resp = self.responses.pop(self.command_seqnro, [])
        fmt = {"seq": self.command_seqnro, "data": resp}
        self.pdbsrv.sendDataFrame(json.dumps(fmt).encode())

    def message(self, msg, lnend='\n'):
        '''Log an output message.
           JSON: "message" : str()
        '''
        self.append_response({"message": msg + lnend})

    def error(self, msg, lnend='\n'):
        '''Log an error message.
           JSON: "error" : str()
        '''
        self.append_response({"error": msg + lnend})

    def postloop(self):
        '''Prepare resuming the inferior.'''
        # Prune deleted breakpoints.
        for bpnum in self.deleted_breaks:
            self.clear_bpbynumber(bpnum)
        self.deleted_breaks.clear()
        self.currentbp = 0
        # About to return from enter_debugger(), thus allow the client to
        # interrupt the current operation.
        self.pdbsrv.sendCmdFrame(kdevpdbconn.Cmd.InterruptAllowed)
        # No need to hold onto the captured state.
        self.forget_caught_values()

    def preloop(self):
        '''Handle suspension of inferior.'''
        # Disallow interrupting.
        self.pdbsrv.sendCmdFrame(kdevpdbconn.Cmd.InterruptDisallowed)

        if not self.debugger_initialized:
            # Complete the preinit handshake with the client.
            _, self.debugger_initialized = self.get_next_request()
            if not self.debugger_initialized:
                return
            self.message("The program started successfully.")
            self.debugger_initialized = True
        # Reset the active frame to top most.
        self.activeindex = self.topindex
        # Send a "frames" response of the top-most inferior frame.
        # JSON: "frames" : [{}]
        self.append_response({"frames": [self.make_frame_entry(self.stack[self.topindex])]})

        # Send a "bphit" response if a breakpoint got hit.
        if self.currentbp:
            try:
                bp = self.get_bpbynumber(self.currentbp)
                self.append_response({'bphit': {"id": int(self.currentbp)
                                                , "filename": bp.file, "line": bp.line
                                                , "hits": bp.hits}})
            except ValueError:
                pass

        if hasattr(self, 'restore_brks'):
            # Re-enable breakpoints that runtolocation() disabled.
            for bpnum in self.restore_brks[1:]:
                self.get_bpbynumber(bpnum).enable()
            # Ensure self.restore_brks[0] is deleted even if it wasn't hit.
            self.clear_bpbynumber(self.restore_brks[0])
            del self.restore_brks

    def get_next_request(self):
        '''Wait for a request.'''
        try:
            request = json.loads(self.pdbsrv.getDataFrame().decode())
            assert isinstance(request, dict)
            assert "seq" in request
            self.command_seqnro = int(request["seq"])
            return request, True
        except kdevpdbconn.Stop:
            self.pdbsrv.stop()
            self.set_quit()
            return {}, False

    def enter_debugger(self):
        self.preloop()
        while True:
            # Send a response.
            self.send_response()
            # Wait for a request.
            request, ok = self.get_next_request()
            if not ok:
                return
            if "input" not in request:
                # A no-op request: send back the seqnro.
                continue
            cmd_and_args = request["input"]
            assert isinstance(cmd_and_args, list)
            assert len(cmd_and_args) > 0
            method_name = cmd_and_args[0]
            try:
                # dispatch a call to 'do_' method.
                cmd_dispatch = getattr(self, 'do_' + method_name)
                method_args = tuple(cmd_and_args[1:])
                if cmd_dispatch(*method_args):
                    # The command needs to resume the inferior.
                    self.postloop()
                    return
            except (AttributeError, TypeError):
                self.error(f"Invalid command: '{cmd_and_args}'")
                raise

    def make_frame_entry(self, frameinfo):
        '''Make a JSON response from a FrameInfo.'''
        return {"current": (frameinfo.frame is self.curframe),
                "filename": str(frameinfo.filename),
                "line": int(frameinfo.lineno),
                "address": int(frameinfo.frame.f_lasti),
                "function": str(frameinfo.fn)}

    def do_where(self):
        '''where(): Report a full stack trace, with the most recent frame
           at the front of the list.
           JSON: "frames" : [{},...]
        '''
        # Dump the inferior frame info.
        framelist = reversed([self.make_frame_entry(f) for f in self.get_inferior_stack()])
        self.append_response({"frames": list(framelist)})

    def do_selectframe(self, whichframe):
        '''Select the active stack-frame.
           JSON: "activeframe" : <int>
        '''
        # KDevelop expects most recent frame to be at index zero,
        # which is reversed to what we have in self.stack.
        kdevframe = max(min(int(whichframe), len(self.get_inferior_stack()) - 1), 0)
        self.activeindex = min(max(self.bottomindex, self.topindex - kdevframe), self.topindex)
        self.append_response({"activeframe": kdevframe})

    def do_continue(self):
        '''Resume the inferior.'''
        self.set_continue()
        return 1

    def do_step(self):
        '''Step into called code.'''
        self.set_step()
        return 1

    def do_next(self):
        '''Step over to next line.'''
        self.set_next(self.curframe)
        return 1

    def do_stepout(self):
        '''Step-out of a frame.'''
        if self.topindex > self.bottomindex:
            # Stop immediately after exiting from the frame.
            self.set_return(self.curframe)
        else:
            # No outer frames left, single step.
            self.set_next(self.curframe)
        return 1

    def do_steppast(self):
        '''Step-out of a function or past a conditional block of code.'''
        self.set_stepout()
        return 1

    def do_quit(self):
        '''Quit.'''
        self.set_quit()
        return 1

    def do_jump(self, lineno):
        '''Set the next line to be executed.'''
        try:
            self.curframe.f_lineno = int(lineno)
        except ValueError:
            self.error(f"Jump to location '{self.stack[self.topindex].filename}:{lineno}' failed!")
        finally:
            self.switch_namespaces()
            self.setup_frames()
            self.switch_namespaces()
            self.append_response({"frames": [self.make_frame_entry(self.stack[self.topindex])]})

    def do_break(self, filename, lineno, disabled):
        '''Try set a breakpoint at filename:lineno location and possibly disable it by default.
           JSON: "breakpoints": [{}] (single item) breakpoint details.
        '''
        if self.is_runnable_srcline(filename, int(lineno)) < 0:
            return
        bpnum = Breakpoint.next
        notok = self.set_break(filename, int(lineno))
        if notok:
            self.error(notok)
            return
        if disabled:
            self.get_bpbynumber(bpnum).disable()
        self.append_response({"breakpoints": [{"id": bpnum, "filename": filename, "line": lineno}]})

    def do_tbreak(self, filename, lineno):
        '''Try set a temporary breakpoint at filename:lineno location.'''
        if self.is_runnable_srcline(filename, int(lineno)) < 0:
            return
        bpnum = Breakpoint.next
        notok = self.set_break(filename, int(lineno), True)
        if notok:
            self.error(notok)
        else:
            self.append_response({"breakpoints": [{"id": bpnum, "filename": filename, "line": lineno}]})

    def do_runtolocation(self, filename, lineno, disable):
        '''Try set a temporary breakpoint at filename:lineno location.
           If successful, disable all other breakpoints if disable is set and then resume the inferior.
           Later, when the (temporary) breakpoint is reached or the debugger is interrupted,
           the enabled state of the modified breakpoints is restored.
        '''
        if self.is_runnable_srcline(filename, int(lineno)) < 0:
            self.append_response({"frames": [self.make_frame_entry(self.stack[self.topindex])]})
            return 0
        bpnum = Breakpoint.next
        notok = self.set_break(filename, int(lineno), True)
        if notok:
            self.error(notok)
            self.append_response({"frames": [self.make_frame_entry(self.stack[self.topindex])]})
            return 0
        # Ok.
        self.append_response({"breakpoints": [{"id": bpnum, "filename": filename, "line": lineno}]})
        restore_brks = [bpnum]
        if disable:
            for bp in Breakpoint.bpbynumber:
                if bp and bp.enabled and bp.number != bpnum:
                    restore_brks.append(bp.number)
                    bp.disable()
        setattr(self, 'restore_brks', restore_brks)
        self.set_continue()
        return 1

    def do_enable(self, bpnum):
        '''Enable a breakpoint'''
        try:
            bp = self.get_bpbynumber(int(bpnum))
            bp.enable()
        except ValueError as e:
            self.error(str(e))

    def do_disable(self, bpnum):
        '''Disable a breakpoint'''
        try:
            bp = self.get_bpbynumber(int(bpnum))
            bp.disable()
        except ValueError as e:
            self.error(str(e))

    def do_clear(self, arg):
        '''Implement Bdb's do_clear()'''
        # We cannot simply delete the breakpoint here. This would make preloop()
        # unable to report hit temporary breakpoints. Because of this,
        # the deletion is deferred into postloop().
        try:
            bp = self.get_bpbynumber(arg)
            self.deleted_breaks.add(bp.number)
        except ValueError as e:
            self.error(str(e))

    def get_topindex(self):
        return self.topindex

    def do_cleanupobjects(self):
        '''Cleanup invalidated state after pausing'''
        response = self.cleanupobjects()
        self.append_response({'released': response})

    def do_enumeratevariables(self, parentid, ns_id, num):
        '''JSON: 'variables': [{'expression': str(<name>), 'ptr': int() }
           OR None, ...]
        '''
        # Required parameters are:
        # parentid:   The object's handle to enumerate.
        # ns_id:      A namespace id. (If the parentid is an namespace handle the ns_id is ignored.)
        # num:        Count of handles to report.
        parentid, ns_id, num = int(parentid), int(ns_id), int(num)
        report = []
        for _ in range(num):
            result = self.enumerateHandle(parentid, ns_id)
            report.append(result)
            if result is None:
                # The enumeration was exhausted.
                break
        # Report.
        self.append_response({'variables': report})

    def do_inspectvalue(self, handle, ns_id):
        ''' Determine the variable's value and the number of children items, if any.
            JSON: 'inspect': inspectvalue()
        '''
        handle, ns_id = int(handle), int(ns_id)
        response = self.inspectvalue(handle, ns_id)
        self.append_response({"inspect": response})

    def do_framelocals(self):
        '''Begin enumerating local variables from the active stack frame.'''
        frame_id = self.activeindex
        # The self.bottomindex frame object .f_locals has some weirdness going on:
        # for x in range(2):
        #     print(x) # <== .f_locals['x'] is zero on the *second iteration of the loop* on this line.
        # Since there is no difference to .f_globals in this frame, except that it gives
        # us the right result, it is used in place of .f_locals.
        if frame_id <= self.bottomindex:
            ref_locals = self.stack[frame_id].f_globals
        else:
            ref_locals = self.stack[frame_id].f_locals
        frame_locals = list(ref_locals.items())
        # The "longname" must stay associated with the same frame object in a event
        # the count of stack frames grows, so use frame_id to make it unique.
        count, objid = self.updateNamespace(frame_locals, frame_id, f"__kdevpdbframeobject{frame_id}")
        self.append_response({'locals': {'count': count, 'ptr': objid, 'namespace': frame_id}})

    def do_globalobjects(self):
        '''Begin enumerating global variables.'''
        globals_ns_id = -1
        globalvars = list(self.stack[self.bottomindex].f_globals.items())
        count, objid = self.updateNamespace(globalvars, globals_ns_id, "__kdevpdbglobals")
        self.append_response({'globals': {'count': count, 'ptr': objid,
                                          'namespace': globals_ns_id}})

    def do_getreturninfo(self):
        '''Begin enumerating program return info'''
        # Synthesize a namespace for:
        # - The return value from the last function/method call.
        # - Exception from the last function/method call.
        returninfo = []
        if self.ret_value is not None:
            returninfo.append(('Return', self.ret_value[0]))
        if self.exc_info is not None:
            # The exception type works as the variable name and when expanded gives:
            # - The parameter(s) passed into the exception's __init__
            # - A stack-frame listing allowing to pin point where the exception was raised.
            exc_type, exc_value, exc_traceback = self.exc_info[0]
            frames = []
            t = exc_traceback
            while t is not None:
                f = t.tb_frame
                filename = self.canonic(f.f_code.co_filename)
                fn = "<lambda>" if not f.f_code.co_name else f.f_code.co_name
                frames.append(f'{filename}:{t.tb_lineno} in {fn}()')
                t = t.tb_next
            exception = {}
            exception[exc_type] = kdevpdbvariablesupport.ExceptionNode(exc_value, frames)
            returninfo.append(('Exception', kdevpdbvariablesupport.Exceptions(exception.values())))
        # Update the namespace.
        count, objid = self.updateNamespace(returninfo, -2, '__kdevpdbreturninfo')
        self.append_response({'returninfo': {'count': count, 'ptr': objid, 'namespace': -2}})

    def do_dropnamespace(self, ns_id):
        '''Discard a namespace id'''
        self.dropNamespace(int(ns_id))

    def do_evalexpression(self, arg, ns_id):
        '''Evaluate an expression in a context of the active stack-frame.
           If it is possible to evaluate the expression the result is attached into a namespace.
           If ns_id != -1, the first argument is ignored and the expression of the namespace id is used.
           Any reported namespace id must be later cleaned up with dropnamespace() command.
           JSON: 'evaluate': {'namespace': <namespace id> or None, 'inscope': bool, 'ptr': <namespace handle>, 'count':1},
                 'variable':{'expression': str(), 'ptr': <expression's handle>}
                 'inspect': inspectvalue()}
        '''
        expr = str(arg)
        if len(expr) <= 2:
            self.append_response({'evaluate': {'namespace': None}})
            return
        ns_id = int(ns_id)
        frameindex = self.activeindex if self.activeindex != -1 else self.topindex
        if ns_id != -1:
            if ns_id not in self.objectsByNamespace:
                # Invalid. This happens when a variable gets carried over to a new session.
                self.append_response({'evaluate': {'namespace': ns_id, 'inscope': False}})
                return
            # Get the variable details
            details = self.objectsByNamespace[ns_id].label.split('/')
            frameindex = int(details[2])
            if frameindex > self.topindex:
                self.append_response({'evaluate': {'namespace': ns_id, 'inscope': False}})
                return
            expr = details[3]
        expr = expr[1:-1]
        # Evaluate.
        evalresult = self.evalexpression(expr, self.stack[frameindex])
        if evalresult['error']:
            if ns_id == -1:
                self.append_response({'evaluate': {'namespace': None}})
            else:
                self.append_response({'evaluate': {'namespace': ns_id, 'inscope': False}})
            return
        if ns_id == -1:
            # create an new namespace id
            ns_id, self.variableNsids = self.variableNsids, self.variableNsids - 1
        # Attach the (new) value to the namespace.
        # The namespace label contains the originating frame and the quoted expression.
        label = f"__kdevpdbvariable/{ns_id}/{frameindex}/'{expr}'"
        _, ns_handle = self.updateNamespace([(expr, evalresult['value'])], ns_id, label)
        # Enumerate the namespace so the client can skip this.
        result = self.enumerateHandle(ns_handle, ns_id)
        # Also inspect the handle.
        inspect = self.inspectvalue(result['ptr'], ns_id)
        self.append_response({'evaluate': {'namespace': ns_id, 'inscope': True, 'ptr': ns_handle, 'count': 1},
                              'variable': result,
                              'inspect': inspect})


def main():
    """Kdevelop python debugger main."""
    # Target command line is expected after the first '--'.
    split = [i for i in range(len(sys.argv)) if sys.argv[i] == '--']
    if not split or split[0] + 1 >= len(sys.argv):
        sys.exit(2)

    split = split[0]
    opts, args = getopt.getopt(sys.argv[1:split], 's:m:')

    if len(opts) < 1 or args:
        sys.exit(2)

    socketpath = [optarg for opt, optarg in opts if opt == '-s'][0]
    args = sys.argv[split+1:]

    if any(opt in ['-m'] for opt, optarg in opts):
        cls = _ModuleTarget
    elif args[0].endswith('.pyz'):
        cls = _ZipTarget
    else:
        cls = _ScriptTarget

    target = cls(args[0])
    sys.argv[:] = args      # Hide "kdevpdb.py" and kdevpdb options from argument list.
    debugger = kdevPdb(socketpath)
    exitcode = 0
    try:
        debugger.run_target(target)
    except SystemExit as e:
        # In most cases SystemExit does not warrant a post-mortem session.
        print("The program exited via sys.exit(). Exit status:", end=' ')
        print(e)
    except SyntaxError:
        print("Syntax error:")
        traceback.print_exc()
        exitcode = 1
    except BaseException as e:
        debugger.enter(e)
        exitcode = 1
    debugger.pdbsrv.stop()
    sys.exit(exitcode)

if __name__ == '__main__':
    main()



"""This file contains auto-generated documentation extracted
from python run-time information. It is analyzed by KDevelop
to offer features such as code-completion and syntax highlighting.
If you discover errors in KDevelop's support for this module,
you can edit this file to correct the errors, e.g. you can add
additional return statements to functions to control the return
type to be used for that function by the analyzer.
Make sure to keep a copy of your changes so you don't accidentally
overwrite them by re-generating the file.
If you do significant improvements, consider sharing the file
with others through the Settings -> Configure KDevelop -> Python Documentation data
module!"""

class defaultdict:
    __doc__ = str()
    __hash__ = None
    def clear(self, _):
        """D.clear() -> None.  Remove all items from D."""
        return None
    def copy(self, _):
        """D.copy() -> a shallow copy of D."""
        return None
    default_factory = member_descriptor()
    def _fromkeys(self, _):
        """Returns a new dict with keys from iterable and values equal to value."""
        return None
    def get(self, k, d=None):
        """D.get(k[,d]) -> D[k] if k in D, else d.  d defaults to None."""
        return None
    def items(self, _):
        """D.items() -> a set-like object providing a view on D's items"""
        return None
    def keys(self, _):
        """D.keys() -> a set-like object providing a view on D's keys"""
        return None
    def pop(self, k, d=None):
        """D.pop(k[,d]) -> v, remove specified key and return the corresponding value.
        If key is not found, d is returned if given, otherwise KeyError is raised"""
        return None
    def popitem(self, _):
        """D.popitem() -> (k, v), remove and return some (key, value) pair as a
        2-tuple; but raise KeyError if D is empty."""
        return None
    def setdefault(self, k, d=None):
        """D.setdefault(k[,d]) -> D.get(k,d), also set D[k]=d if k not in D"""
        return None
    def update(self, E=None, F=None):
        """D.update([E, ]**F) -> None.  Update D from dict/iterable E and F.
        If E is present and has a .keys() method, then does:  for k in E: D[k] = E[k]
        If E is present and lacks a .keys() method, then does:  for k, v in E: D[k] = v
        In either case, this is followed by: for k in F:  D[k] = F[k]"""
        return None
    def values(self, _):
        """D.values() -> an object providing a view on D's values"""
        return None

class deque:
    """ ! TypeContainer ! """
    __doc__ = str()
    __hash__ = None
    def __init__(self):
        """! returnContentEqualsContentOf ! 0"""
        return deque()
    def append(self, _):
        """Add an element to the right side of the deque.
        ! addsTypeOfArg ! 0"""
        return None
    def appendleft(self, _):
        """
        ! addsTypeOfArg ! 0
        Add an element to the left side of the deque."""
        return None
    def clear(self, _):
        """Remove all elements from the deque."""
        return None
    def copy(self, _):
        """Return a shallow copy of a deque."""
        return deque()
    def count(self, value):
        """D.count(value) -> integer -- return number of occurrences of value"""
        return 0
    def extend(self, _):
        """! addsTypeOfArgContent ! 0
        Extend the right side of the deque with elements from the iterable"""
        return None
    def extendleft(self, _):
        """! addsTypeOfArgContent ! 0
        Extend the left side of the deque with elements from the iterable"""
        return None
    def index(self, value, start=None, stop=None):
        """D.index(value, [start, [stop]]) -> integer -- return first index of value.
        Raises ValueError if the value is not present."""
        return 0
    def insert(self, index, object):
        """! addsTypeOfArg ! 1
        D.insert(index, object) -- insert object before index"""
        return None
    maxlen = 1
    def pop(self, _):
        """Remove and return the rightmost element."""
        return None
    def popleft(self, _):
        """Remove and return the leftmost element."""
        return None
    def remove(self, value):
        """D.remove(value) -- remove first occurrence of value."""
        return None
    def reverse(self, _):
        """D.reverse() -- reverse *IN PLACE*"""
        return None
    def rotate(self, defaultn=1):
        """Rotate the deque n steps to the right (default n=1).  If n is negative, rotates left."""
        return None



class pyqtSignal():
 def connect(self, targetSignal): pass
 def emit(self, *args): pass
from QtCore import *

from QtWidgets import *

import datetime

class QMaskGenerator(QObject):
    """"""
    def __init__(self, parent = None):
        '''void QMaskGenerator.__init__(QObject parent = None)'''
    def nextMask(self):
        '''abstract int QMaskGenerator.nextMask()'''
        return int()
    def seed(self):
        '''abstract bool QMaskGenerator.seed()'''
        return bool()


class QWebSocket(QObject):
    """"""
    def __init__(self, origin = None, version = None, parent = None):
        '''void QWebSocket.__init__(str origin = '', QWebSocketProtocol.Version version = QWebSocketProtocol.Version13, QObject parent = None)'''
    sslErrors = pyqtSignal() # void sslErrors(const QListlt;QSslErrorgt;amp;) - signal
    bytesWritten = pyqtSignal() # void bytesWritten(qint64) - signal
    pong = pyqtSignal() # void pong(quint64,const QByteArrayamp;) - signal
    binaryMessageReceived = pyqtSignal() # void binaryMessageReceived(const QByteArrayamp;) - signal
    textMessageReceived = pyqtSignal() # void textMessageReceived(const QStringamp;) - signal
    binaryFrameReceived = pyqtSignal() # void binaryFrameReceived(const QByteArrayamp;,bool) - signal
    textFrameReceived = pyqtSignal() # void textFrameReceived(const QStringamp;,bool) - signal
    readChannelFinished = pyqtSignal() # void readChannelFinished() - signal
    proxyAuthenticationRequired = pyqtSignal() # void proxyAuthenticationRequired(const QNetworkProxyamp;,QAuthenticator*) - signal
    stateChanged = pyqtSignal() # void stateChanged(QAbstractSocket::SocketState) - signal
    disconnected = pyqtSignal() # void disconnected() - signal
    connected = pyqtSignal() # void connected() - signal
    aboutToClose = pyqtSignal() # void aboutToClose() - signal
    def ping(self, payload = QByteArray()):
        '''void QWebSocket.ping(QByteArray payload = QByteArray())'''
    def open(self, url):
        '''void QWebSocket.open(QUrl url)'''
    def close(self, closeCode = None, reason = str()):
        '''void QWebSocket.close(QWebSocketProtocol.CloseCode closeCode = QWebSocketProtocol.CloseCodeNormal, str reason = str())'''
    def sslConfiguration(self):
        '''QSslConfiguration QWebSocket.sslConfiguration()'''
        return QSslConfiguration()
    def setSslConfiguration(self, sslConfiguration):
        '''void QWebSocket.setSslConfiguration(QSslConfiguration sslConfiguration)'''
    def ignoreSslErrors(self, errors):
        '''void QWebSocket.ignoreSslErrors(list-of-QSslError errors)'''
    def ignoreSslErrors(self):
        '''void QWebSocket.ignoreSslErrors()'''
    def sendBinaryMessage(self, data):
        '''int QWebSocket.sendBinaryMessage(QByteArray data)'''
        return int()
    def sendTextMessage(self, message):
        '''int QWebSocket.sendTextMessage(str message)'''
        return int()
    def closeReason(self):
        '''str QWebSocket.closeReason()'''
        return str()
    def closeCode(self):
        '''QWebSocketProtocol.CloseCode QWebSocket.closeCode()'''
        return QWebSocketProtocol.CloseCode()
    def origin(self):
        '''str QWebSocket.origin()'''
        return str()
    def requestUrl(self):
        '''QUrl QWebSocket.requestUrl()'''
        return QUrl()
    def resourceName(self):
        '''str QWebSocket.resourceName()'''
        return str()
    def version(self):
        '''QWebSocketProtocol.Version QWebSocket.version()'''
        return QWebSocketProtocol.Version()
    def state(self):
        '''QAbstractSocket.SocketState QWebSocket.state()'''
        return QAbstractSocket.SocketState()
    def setPauseMode(self, pauseMode):
        '''void QWebSocket.setPauseMode(QAbstractSocket.PauseModes pauseMode)'''
    def resume(self):
        '''void QWebSocket.resume()'''
    def setReadBufferSize(self, size):
        '''void QWebSocket.setReadBufferSize(int size)'''
    def readBufferSize(self):
        '''int QWebSocket.readBufferSize()'''
        return int()
    def maskGenerator(self):
        '''QMaskGenerator QWebSocket.maskGenerator()'''
        return QMaskGenerator()
    def setMaskGenerator(self, maskGenerator):
        '''void QWebSocket.setMaskGenerator(QMaskGenerator maskGenerator)'''
    def setProxy(self, networkProxy):
        '''void QWebSocket.setProxy(QNetworkProxy networkProxy)'''
    def proxy(self):
        '''QNetworkProxy QWebSocket.proxy()'''
        return QNetworkProxy()
    def peerPort(self):
        '''int QWebSocket.peerPort()'''
        return int()
    def peerName(self):
        '''str QWebSocket.peerName()'''
        return str()
    def peerAddress(self):
        '''QHostAddress QWebSocket.peerAddress()'''
        return QHostAddress()
    def pauseMode(self):
        '''QAbstractSocket.PauseModes QWebSocket.pauseMode()'''
        return QAbstractSocket.PauseModes()
    def localPort(self):
        '''int QWebSocket.localPort()'''
        return int()
    def localAddress(self):
        '''QHostAddress QWebSocket.localAddress()'''
        return QHostAddress()
    def isValid(self):
        '''bool QWebSocket.isValid()'''
        return bool()
    def flush(self):
        '''bool QWebSocket.flush()'''
        return bool()
    def errorString(self):
        '''str QWebSocket.errorString()'''
        return str()
    def error(self):
        '''QAbstractSocket.SocketError QWebSocket.error()'''
        return QAbstractSocket.SocketError()
    error = pyqtSignal() # void error(QAbstractSocket::SocketError) - signal
    def abort(self):
        '''void QWebSocket.abort()'''


class QWebSocketCorsAuthenticator():
    """"""
    def __init__(self, origin):
        '''void QWebSocketCorsAuthenticator.__init__(str origin)'''
    def __init__(self, other):
        '''void QWebSocketCorsAuthenticator.__init__(QWebSocketCorsAuthenticator other)'''
    def allowed(self):
        '''bool QWebSocketCorsAuthenticator.allowed()'''
        return bool()
    def setAllowed(self, allowed):
        '''void QWebSocketCorsAuthenticator.setAllowed(bool allowed)'''
    def origin(self):
        '''str QWebSocketCorsAuthenticator.origin()'''
        return str()
    def swap(self, other):
        '''void QWebSocketCorsAuthenticator.swap(QWebSocketCorsAuthenticator other)'''


class QWebSocketProtocol():
    """"""
    # Enum QWebSocketProtocol.CloseCode
    CloseCodeNormal = 0
    CloseCodeGoingAway = 0
    CloseCodeProtocolError = 0
    CloseCodeDatatypeNotSupported = 0
    CloseCodeReserved1004 = 0
    CloseCodeMissingStatusCode = 0
    CloseCodeAbnormalDisconnection = 0
    CloseCodeWrongDatatype = 0
    CloseCodePolicyViolated = 0
    CloseCodeTooMuchData = 0
    CloseCodeMissingExtension = 0
    CloseCodeBadOperation = 0
    CloseCodeTlsHandshakeFailed = 0

    # Enum QWebSocketProtocol.Version
    VersionUnknown = 0
    Version0 = 0
    Version4 = 0
    Version5 = 0
    Version6 = 0
    Version7 = 0
    Version8 = 0
    Version13 = 0
    VersionLatest = 0



class QWebSocketServer(QObject):
    """"""
    # Enum QWebSocketServer.SslMode
    SecureMode = 0
    NonSecureMode = 0

    def __init__(self, serverName, secureMode, parent = None):
        '''void QWebSocketServer.__init__(str serverName, QWebSocketServer.SslMode secureMode, QObject parent = None)'''
    closed = pyqtSignal() # void closed() - signal
    sslErrors = pyqtSignal() # void sslErrors(const QListlt;QSslErrorgt;amp;) - signal
    peerVerifyError = pyqtSignal() # void peerVerifyError(const QSslErroramp;) - signal
    newConnection = pyqtSignal() # void newConnection() - signal
    originAuthenticationRequired = pyqtSignal() # void originAuthenticationRequired(QWebSocketCorsAuthenticator*) - signal
    serverError = pyqtSignal() # void serverError(QWebSocketProtocol::CloseCode) - signal
    acceptError = pyqtSignal() # void acceptError(QAbstractSocket::SocketError) - signal
    def serverUrl(self):
        '''QUrl QWebSocketServer.serverUrl()'''
        return QUrl()
    def supportedVersions(self):
        '''list-of-QWebSocketProtocol.Version QWebSocketServer.supportedVersions()'''
        return [QWebSocketProtocol.Version()]
    def sslConfiguration(self):
        '''QSslConfiguration QWebSocketServer.sslConfiguration()'''
        return QSslConfiguration()
    def setSslConfiguration(self, sslConfiguration):
        '''void QWebSocketServer.setSslConfiguration(QSslConfiguration sslConfiguration)'''
    def proxy(self):
        '''QNetworkProxy QWebSocketServer.proxy()'''
        return QNetworkProxy()
    def setProxy(self, networkProxy):
        '''void QWebSocketServer.setProxy(QNetworkProxy networkProxy)'''
    def serverName(self):
        '''str QWebSocketServer.serverName()'''
        return str()
    def setServerName(self, serverName):
        '''void QWebSocketServer.setServerName(str serverName)'''
    def resumeAccepting(self):
        '''void QWebSocketServer.resumeAccepting()'''
    def pauseAccepting(self):
        '''void QWebSocketServer.pauseAccepting()'''
    def errorString(self):
        '''str QWebSocketServer.errorString()'''
        return str()
    def error(self):
        '''QWebSocketProtocol.CloseCode QWebSocketServer.error()'''
        return QWebSocketProtocol.CloseCode()
    def nextPendingConnection(self):
        '''QWebSocket QWebSocketServer.nextPendingConnection()'''
        return QWebSocket()
    def hasPendingConnections(self):
        '''bool QWebSocketServer.hasPendingConnections()'''
        return bool()
    def socketDescriptor(self):
        '''int QWebSocketServer.socketDescriptor()'''
        return int()
    def setSocketDescriptor(self, socketDescriptor):
        '''bool QWebSocketServer.setSocketDescriptor(int socketDescriptor)'''
        return bool()
    def secureMode(self):
        '''QWebSocketServer.SslMode QWebSocketServer.secureMode()'''
        return QWebSocketServer.SslMode()
    def serverAddress(self):
        '''QHostAddress QWebSocketServer.serverAddress()'''
        return QHostAddress()
    def serverPort(self):
        '''int QWebSocketServer.serverPort()'''
        return int()
    def maxPendingConnections(self):
        '''int QWebSocketServer.maxPendingConnections()'''
        return int()
    def setMaxPendingConnections(self, numConnections):
        '''void QWebSocketServer.setMaxPendingConnections(int numConnections)'''
    def isListening(self):
        '''bool QWebSocketServer.isListening()'''
        return bool()
    def close(self):
        '''void QWebSocketServer.close()'''
    def listen(self, address = None, port = 0):
        '''bool QWebSocketServer.listen(QHostAddress address = QHostAddress.Any, int port = 0)'''
        return bool()





class pyqtSignal():
 def connect(self, targetSignal): pass
 def emit(self, *args): pass
from QtCore import *

class QDeclarativeComponent(QObject):
    """"""
    # Enum QDeclarativeComponent.Status
    Null = 0
    Ready = 0
    Loading = 0
    Error = 0

    def __init__(self, parent = None):
        '''QDeclarativeEngine QDeclarativeComponent.__init__(QObject parent = None)'''
        return QDeclarativeEngine()
    def __init__(self, fileName, parent = None):
        '''QDeclarativeEngine QDeclarativeComponent.__init__(QString fileName, QObject parent = None)'''
        return QDeclarativeEngine()
    def __init__(self, url, parent = None):
        '''QDeclarativeEngine QDeclarativeComponent.__init__(QUrl url, QObject parent = None)'''
        return QDeclarativeEngine()
    progressChanged = pyqtSignal() # void progressChanged(qreal) - signal
    statusChanged = pyqtSignal() # void statusChanged(QDeclarativeComponent::Status) - signal
    def creationContext(self):
        '''QDeclarativeContext QDeclarativeComponent.creationContext()'''
        return QDeclarativeContext()
    def setData(self, baseUrl):
        '''QByteArray QDeclarativeComponent.setData(QUrl baseUrl)'''
        return QByteArray()
    def loadUrl(self, url):
        '''void QDeclarativeComponent.loadUrl(QUrl url)'''
    def completeCreate(self):
        '''void QDeclarativeComponent.completeCreate()'''
    def beginCreate(self):
        '''QDeclarativeContext QDeclarativeComponent.beginCreate()'''
        return QDeclarativeContext()
    def create(self, context = None):
        '''QObject QDeclarativeComponent.create(QDeclarativeContext context = None)'''
        return QObject()
    def url(self):
        '''QUrl QDeclarativeComponent.url()'''
        return QUrl()
    def progress(self):
        '''float QDeclarativeComponent.progress()'''
        return float()
    def errors(self):
        '''list-of-QDeclarativeError QDeclarativeComponent.errors()'''
        return [QDeclarativeError()]
    def isLoading(self):
        '''bool QDeclarativeComponent.isLoading()'''
        return bool()
    def isError(self):
        '''bool QDeclarativeComponent.isError()'''
        return bool()
    def isReady(self):
        '''bool QDeclarativeComponent.isReady()'''
        return bool()
    def isNull(self):
        '''bool QDeclarativeComponent.isNull()'''
        return bool()
    def status(self):
        '''QDeclarativeComponent.Status QDeclarativeComponent.status()'''
        return QDeclarativeComponent.Status()


class QDeclarativeContext(QObject):
    """"""
    def __init__(self, engine, parent = None):
        '''void QDeclarativeContext.__init__(QDeclarativeEngine engine, QObject parent = None)'''
    def __init__(self, context, parent = None):
        '''void QDeclarativeContext.__init__(QDeclarativeContext context, QObject parent = None)'''
    def baseUrl(self):
        '''QUrl QDeclarativeContext.baseUrl()'''
        return QUrl()
    def setBaseUrl(self):
        '''QUrl QDeclarativeContext.setBaseUrl()'''
        return QUrl()
    def resolvedUrl(self):
        '''QUrl QDeclarativeContext.resolvedUrl()'''
        return QUrl()
    def setContextProperty(self):
        '''QObject QDeclarativeContext.setContextProperty()'''
        return QObject()
    def setContextProperty(self):
        '''QVariant QDeclarativeContext.setContextProperty()'''
        return QVariant()
    def contextProperty(self):
        '''QString QDeclarativeContext.contextProperty()'''
        return QString()
    def setContextObject(self):
        '''QObject QDeclarativeContext.setContextObject()'''
        return QObject()
    def contextObject(self):
        '''QObject QDeclarativeContext.contextObject()'''
        return QObject()
    def parentContext(self):
        '''QDeclarativeContext QDeclarativeContext.parentContext()'''
        return QDeclarativeContext()
    def engine(self):
        '''QDeclarativeEngine QDeclarativeContext.engine()'''
        return QDeclarativeEngine()
    def isValid(self):
        '''bool QDeclarativeContext.isValid()'''
        return bool()


class QDeclarativeEngine(QObject):
    """"""
    # Enum QDeclarativeEngine.ObjectOwnership
    CppOwnership = 0
    JavaScriptOwnership = 0

    def __init__(self, parent = None):
        '''void QDeclarativeEngine.__init__(QObject parent = None)'''
    warnings = pyqtSignal() # void warnings(const QListlt;QDeclarativeErrorgt;amp;) - signal
    quit = pyqtSignal() # void quit() - signal
    def objectOwnership(self):
        '''static QObject QDeclarativeEngine.objectOwnership()'''
        return QObject()
    def setObjectOwnership(self):
        '''static QDeclarativeEngine.ObjectOwnership QDeclarativeEngine.setObjectOwnership()'''
        return QDeclarativeEngine.ObjectOwnership()
    def setContextForObject(self):
        '''static QDeclarativeContext QDeclarativeEngine.setContextForObject()'''
        return QDeclarativeContext()
    def contextForObject(self):
        '''static QObject QDeclarativeEngine.contextForObject()'''
        return QObject()
    def setOutputWarningsToStandardError(self):
        '''bool QDeclarativeEngine.setOutputWarningsToStandardError()'''
        return bool()
    def outputWarningsToStandardError(self):
        '''bool QDeclarativeEngine.outputWarningsToStandardError()'''
        return bool()
    def setBaseUrl(self):
        '''QUrl QDeclarativeEngine.setBaseUrl()'''
        return QUrl()
    def baseUrl(self):
        '''QUrl QDeclarativeEngine.baseUrl()'''
        return QUrl()
    def offlineStoragePath(self):
        '''QString QDeclarativeEngine.offlineStoragePath()'''
        return QString()
    def setOfflineStoragePath(self, dir):
        '''void QDeclarativeEngine.setOfflineStoragePath(QString dir)'''
    def removeImageProvider(self, id):
        '''void QDeclarativeEngine.removeImageProvider(QString id)'''
    def imageProvider(self, id):
        '''QDeclarativeImageProvider QDeclarativeEngine.imageProvider(QString id)'''
        return QDeclarativeImageProvider()
    def addImageProvider(self, id):
        '''QDeclarativeImageProvider QDeclarativeEngine.addImageProvider(QString id)'''
        return QDeclarativeImageProvider()
    def networkAccessManager(self):
        '''QNetworkAccessManager QDeclarativeEngine.networkAccessManager()'''
        return QNetworkAccessManager()
    def networkAccessManagerFactory(self):
        '''QDeclarativeNetworkAccessManagerFactory QDeclarativeEngine.networkAccessManagerFactory()'''
        return QDeclarativeNetworkAccessManagerFactory()
    def setNetworkAccessManagerFactory(self):
        '''QDeclarativeNetworkAccessManagerFactory QDeclarativeEngine.setNetworkAccessManagerFactory()'''
        return QDeclarativeNetworkAccessManagerFactory()
    def importPlugin(self, filePath, uri, errorString):
        '''bool QDeclarativeEngine.importPlugin(QString filePath, QString uri, QString errorString)'''
        return bool()
    def addPluginPath(self, dir):
        '''void QDeclarativeEngine.addPluginPath(QString dir)'''
    def setPluginPathList(self, paths):
        '''void QDeclarativeEngine.setPluginPathList(QStringList paths)'''
    def pluginPathList(self):
        '''QStringList QDeclarativeEngine.pluginPathList()'''
        return QStringList()
    def addImportPath(self, dir):
        '''void QDeclarativeEngine.addImportPath(QString dir)'''
    def setImportPathList(self, paths):
        '''void QDeclarativeEngine.setImportPathList(QStringList paths)'''
    def importPathList(self):
        '''QStringList QDeclarativeEngine.importPathList()'''
        return QStringList()
    def clearComponentCache(self):
        '''void QDeclarativeEngine.clearComponentCache()'''
    def rootContext(self):
        '''QDeclarativeContext QDeclarativeEngine.rootContext()'''
        return QDeclarativeContext()


class QDeclarativeError():
    """"""
    def __init__(self):
        '''void QDeclarativeError.__init__()'''
    def __init__(self):
        '''QDeclarativeError QDeclarativeError.__init__()'''
        return QDeclarativeError()
    def toString(self):
        '''QString QDeclarativeError.toString()'''
        return QString()
    def setColumn(self):
        '''int QDeclarativeError.setColumn()'''
        return int()
    def column(self):
        '''int QDeclarativeError.column()'''
        return int()
    def setLine(self):
        '''int QDeclarativeError.setLine()'''
        return int()
    def line(self):
        '''int QDeclarativeError.line()'''
        return int()
    def setDescription(self):
        '''QString QDeclarativeError.setDescription()'''
        return QString()
    def description(self):
        '''QString QDeclarativeError.description()'''
        return QString()
    def setUrl(self):
        '''QUrl QDeclarativeError.setUrl()'''
        return QUrl()
    def url(self):
        '''QUrl QDeclarativeError.url()'''
        return QUrl()
    def isValid(self):
        '''bool QDeclarativeError.isValid()'''
        return bool()


class QDeclarativeExpression(QObject):
    """"""
    def __init__(self):
        '''void QDeclarativeExpression.__init__()'''
    def __init__(self, parent = None):
        '''QString QDeclarativeExpression.__init__(QObject parent = None)'''
        return QString()
    valueChanged = pyqtSignal() # void valueChanged() - signal
    def evaluate(self, valueIsUndefined):
        '''QVariant QDeclarativeExpression.evaluate(bool valueIsUndefined)'''
        return QVariant()
    def error(self):
        '''QDeclarativeError QDeclarativeExpression.error()'''
        return QDeclarativeError()
    def clearError(self):
        '''void QDeclarativeExpression.clearError()'''
    def hasError(self):
        '''bool QDeclarativeExpression.hasError()'''
        return bool()
    def scopeObject(self):
        '''QObject QDeclarativeExpression.scopeObject()'''
        return QObject()
    def setSourceLocation(self, fileName, line):
        '''void QDeclarativeExpression.setSourceLocation(QString fileName, int line)'''
    def lineNumber(self):
        '''int QDeclarativeExpression.lineNumber()'''
        return int()
    def sourceFile(self):
        '''QString QDeclarativeExpression.sourceFile()'''
        return QString()
    def setNotifyOnValueChanged(self):
        '''bool QDeclarativeExpression.setNotifyOnValueChanged()'''
        return bool()
    def notifyOnValueChanged(self):
        '''bool QDeclarativeExpression.notifyOnValueChanged()'''
        return bool()
    def setExpression(self):
        '''QString QDeclarativeExpression.setExpression()'''
        return QString()
    def expression(self):
        '''QString QDeclarativeExpression.expression()'''
        return QString()
    def context(self):
        '''QDeclarativeContext QDeclarativeExpression.context()'''
        return QDeclarativeContext()
    def engine(self):
        '''QDeclarativeEngine QDeclarativeExpression.engine()'''
        return QDeclarativeEngine()


class QDeclarativeExtensionPlugin(QObject):
    """"""
    def __init__(self, parent = None):
        '''void QDeclarativeExtensionPlugin.__init__(QObject parent = None)'''
    def initializeEngine(self, engine, uri):
        '''void QDeclarativeExtensionPlugin.initializeEngine(QDeclarativeEngine engine, str uri)'''
    def registerTypes(self, uri):
        '''abstract void QDeclarativeExtensionPlugin.registerTypes(str uri)'''


class QDeclarativeImageProvider():
    """"""
    # Enum QDeclarativeImageProvider.ImageType
    Image = 0
    Pixmap = 0

    def __init__(self, type):
        '''void QDeclarativeImageProvider.__init__(QDeclarativeImageProvider.ImageType type)'''
    def __init__(self):
        '''QDeclarativeImageProvider QDeclarativeImageProvider.__init__()'''
        return QDeclarativeImageProvider()
    def requestPixmap(self, id, size, requestedSize):
        '''QPixmap QDeclarativeImageProvider.requestPixmap(QString id, QSize size, QSize requestedSize)'''
        return QPixmap()
    def requestImage(self, id, size, requestedSize):
        '''QImage QDeclarativeImageProvider.requestImage(QString id, QSize size, QSize requestedSize)'''
        return QImage()
    def imageType(self):
        '''QDeclarativeImageProvider.ImageType QDeclarativeImageProvider.imageType()'''
        return QDeclarativeImageProvider.ImageType()


class QDeclarativeParserStatus():
    """"""
    def __init__(self):
        '''void QDeclarativeParserStatus.__init__()'''
    def __init__(self):
        '''QDeclarativeParserStatus QDeclarativeParserStatus.__init__()'''
        return QDeclarativeParserStatus()
    def componentComplete(self):
        '''abstract void QDeclarativeParserStatus.componentComplete()'''
    def classBegin(self):
        '''abstract void QDeclarativeParserStatus.classBegin()'''


class QDeclarativeItem(QGraphicsObject, QDeclarativeParserStatus):
    """"""
    # Enum QDeclarativeItem.TransformOrigin
    TopLeft = 0
    Top = 0
    TopRight = 0
    Left = 0
    Center = 0
    Right = 0
    BottomLeft = 0
    Bottom = 0
    BottomRight = 0

    def __init__(self, parent = None):
        '''void QDeclarativeItem.__init__(QDeclarativeItem parent = None)'''
    def geometryChanged(self, newGeometry, oldGeometry):
        '''void QDeclarativeItem.geometryChanged(QRectF newGeometry, QRectF oldGeometry)'''
    def inputMethodQuery(self, query):
        '''QVariant QDeclarativeItem.inputMethodQuery(Qt.InputMethodQuery query)'''
        return QVariant()
    def inputMethodEvent(self):
        '''QInputMethodEvent QDeclarativeItem.inputMethodEvent()'''
        return QInputMethodEvent()
    def keyReleaseEvent(self, event):
        '''void QDeclarativeItem.keyReleaseEvent(QKeyEvent event)'''
    def keyPressEvent(self, event):
        '''void QDeclarativeItem.keyPressEvent(QKeyEvent event)'''
    def componentComplete(self):
        '''void QDeclarativeItem.componentComplete()'''
    def classBegin(self):
        '''void QDeclarativeItem.classBegin()'''
    def heightValid(self):
        '''bool QDeclarativeItem.heightValid()'''
        return bool()
    def setImplicitHeight(self):
        '''float QDeclarativeItem.setImplicitHeight()'''
        return float()
    def widthValid(self):
        '''bool QDeclarativeItem.widthValid()'''
        return bool()
    def setImplicitWidth(self):
        '''float QDeclarativeItem.setImplicitWidth()'''
        return float()
    def itemChange(self):
        '''QVariant QDeclarativeItem.itemChange()'''
        return QVariant()
    def event(self):
        '''QEvent QDeclarativeItem.event()'''
        return QEvent()
    def sceneEvent(self):
        '''QEvent QDeclarativeItem.sceneEvent()'''
        return QEvent()
    def isComponentComplete(self):
        '''bool QDeclarativeItem.isComponentComplete()'''
        return bool()
    def setKeepMouseGrab(self):
        '''bool QDeclarativeItem.setKeepMouseGrab()'''
        return bool()
    def keepMouseGrab(self):
        '''bool QDeclarativeItem.keepMouseGrab()'''
        return bool()
    def hasFocus(self):
        '''bool QDeclarativeItem.hasFocus()'''
        return bool()
    def paint(self):
        '''QWidget QDeclarativeItem.paint()'''
        return QWidget()
    def boundingRect(self):
        '''QRectF QDeclarativeItem.boundingRect()'''
        return QRectF()
    def setSmooth(self):
        '''bool QDeclarativeItem.setSmooth()'''
        return bool()
    def smooth(self):
        '''bool QDeclarativeItem.smooth()'''
        return bool()
    def setTransformOrigin(self):
        '''QDeclarativeItem.TransformOrigin QDeclarativeItem.setTransformOrigin()'''
        return QDeclarativeItem.TransformOrigin()
    def transformOrigin(self):
        '''QDeclarativeItem.TransformOrigin QDeclarativeItem.transformOrigin()'''
        return QDeclarativeItem.TransformOrigin()
    def implicitHeight(self):
        '''float QDeclarativeItem.implicitHeight()'''
        return float()
    def setHeight(self):
        '''float QDeclarativeItem.setHeight()'''
        return float()
    def implicitWidth(self):
        '''float QDeclarativeItem.implicitWidth()'''
        return float()
    def setWidth(self):
        '''float QDeclarativeItem.setWidth()'''
        return float()
    def setBaselineOffset(self):
        '''float QDeclarativeItem.setBaselineOffset()'''
        return float()
    def baselineOffset(self):
        '''float QDeclarativeItem.baselineOffset()'''
        return float()
    def setClip(self):
        '''bool QDeclarativeItem.setClip()'''
        return bool()
    def clip(self):
        '''bool QDeclarativeItem.clip()'''
        return bool()
    def childrenRect(self):
        '''QRectF QDeclarativeItem.childrenRect()'''
        return QRectF()
    def setParentItem(self, parent):
        '''void QDeclarativeItem.setParentItem(QDeclarativeItem parent)'''
    def parentItem(self):
        '''QDeclarativeItem QDeclarativeItem.parentItem()'''
        return QDeclarativeItem()


class QDeclarativeListReference():
    """"""
    def __init__(self):
        '''void QDeclarativeListReference.__init__()'''
    def __init__(self, property, engine = None):
        '''QObject QDeclarativeListReference.__init__(str property, QDeclarativeEngine engine = None)'''
        return QObject()
    def __init__(self):
        '''QDeclarativeListReference QDeclarativeListReference.__init__()'''
        return QDeclarativeListReference()
    def count(self):
        '''int QDeclarativeListReference.count()'''
        return int()
    def clear(self):
        '''bool QDeclarativeListReference.clear()'''
        return bool()
    def at(self):
        '''int QDeclarativeListReference.at()'''
        return int()
    def append(self):
        '''QObject QDeclarativeListReference.append()'''
        return QObject()
    def canCount(self):
        '''bool QDeclarativeListReference.canCount()'''
        return bool()
    def canClear(self):
        '''bool QDeclarativeListReference.canClear()'''
        return bool()
    def canAt(self):
        '''bool QDeclarativeListReference.canAt()'''
        return bool()
    def canAppend(self):
        '''bool QDeclarativeListReference.canAppend()'''
        return bool()
    def listElementType(self):
        '''QMetaObject QDeclarativeListReference.listElementType()'''
        return QMetaObject()
    def object(self):
        '''QObject QDeclarativeListReference.object()'''
        return QObject()
    def isValid(self):
        '''bool QDeclarativeListReference.isValid()'''
        return bool()


class QDeclarativeNetworkAccessManagerFactory():
    """"""
    def __init__(self):
        '''void QDeclarativeNetworkAccessManagerFactory.__init__()'''
    def __init__(self):
        '''QDeclarativeNetworkAccessManagerFactory QDeclarativeNetworkAccessManagerFactory.__init__()'''
        return QDeclarativeNetworkAccessManagerFactory()
    def create(self, parent):
        '''abstract QNetworkAccessManager QDeclarativeNetworkAccessManagerFactory.create(QObject parent)'''
        return QNetworkAccessManager()


class QDeclarativeProperty():
    """"""
    # Enum QDeclarativeProperty.Type
    Invalid = 0
    Property = 0
    SignalProperty = 0

    # Enum QDeclarativeProperty.PropertyTypeCategory
    InvalidCategory = 0
    List = 0
    Object = 0
    Normal = 0

    def __init__(self):
        '''void QDeclarativeProperty.__init__()'''
    def __init__(self):
        '''QObject QDeclarativeProperty.__init__()'''
        return QObject()
    def __init__(self):
        '''QDeclarativeContext QDeclarativeProperty.__init__()'''
        return QDeclarativeContext()
    def __init__(self):
        '''QDeclarativeEngine QDeclarativeProperty.__init__()'''
        return QDeclarativeEngine()
    def __init__(self):
        '''QString QDeclarativeProperty.__init__()'''
        return QString()
    def __init__(self):
        '''QDeclarativeContext QDeclarativeProperty.__init__()'''
        return QDeclarativeContext()
    def __init__(self):
        '''QDeclarativeEngine QDeclarativeProperty.__init__()'''
        return QDeclarativeEngine()
    def __init__(self):
        '''QDeclarativeProperty QDeclarativeProperty.__init__()'''
        return QDeclarativeProperty()
    def __ne__(self):
        '''QDeclarativeProperty QDeclarativeProperty.__ne__()'''
        return QDeclarativeProperty()
    def __hash__(self):
        '''int QDeclarativeProperty.__hash__()'''
        return int()
    def method(self):
        '''QMetaMethod QDeclarativeProperty.method()'''
        return QMetaMethod()
    def property(self):
        '''QMetaProperty QDeclarativeProperty.property()'''
        return QMetaProperty()
    def index(self):
        '''int QDeclarativeProperty.index()'''
        return int()
    def object(self):
        '''QObject QDeclarativeProperty.object()'''
        return QObject()
    def isResettable(self):
        '''bool QDeclarativeProperty.isResettable()'''
        return bool()
    def isDesignable(self):
        '''bool QDeclarativeProperty.isDesignable()'''
        return bool()
    def isWritable(self):
        '''bool QDeclarativeProperty.isWritable()'''
        return bool()
    def connectNotifySignal(self, dest, slot):
        '''bool QDeclarativeProperty.connectNotifySignal(QObject dest, SLOT() slot)'''
        return bool()
    def connectNotifySignal(self, dest):
        '''bool QDeclarativeProperty.connectNotifySignal(callable dest)'''
        return bool()
    def connectNotifySignal(self, dest, method):
        '''bool QDeclarativeProperty.connectNotifySignal(QObject dest, int method)'''
        return bool()
    def needsNotifySignal(self):
        '''bool QDeclarativeProperty.needsNotifySignal()'''
        return bool()
    def hasNotifySignal(self):
        '''bool QDeclarativeProperty.hasNotifySignal()'''
        return bool()
    def reset(self):
        '''bool QDeclarativeProperty.reset()'''
        return bool()
    def write(self):
        '''QVariant QDeclarativeProperty.write()'''
        return QVariant()
    def write(self):
        '''static QVariant QDeclarativeProperty.write()'''
        return QVariant()
    def write(self):
        '''static QDeclarativeContext QDeclarativeProperty.write()'''
        return QDeclarativeContext()
    def write(self):
        '''static QDeclarativeEngine QDeclarativeProperty.write()'''
        return QDeclarativeEngine()
    def read(self):
        '''QVariant QDeclarativeProperty.read()'''
        return QVariant()
    def read(self):
        '''static QString QDeclarativeProperty.read()'''
        return QString()
    def read(self):
        '''static QDeclarativeContext QDeclarativeProperty.read()'''
        return QDeclarativeContext()
    def read(self):
        '''static QDeclarativeEngine QDeclarativeProperty.read()'''
        return QDeclarativeEngine()
    def name(self):
        '''QString QDeclarativeProperty.name()'''
        return QString()
    def propertyTypeName(self):
        '''str QDeclarativeProperty.propertyTypeName()'''
        return str()
    def propertyTypeCategory(self):
        '''QDeclarativeProperty.PropertyTypeCategory QDeclarativeProperty.propertyTypeCategory()'''
        return QDeclarativeProperty.PropertyTypeCategory()
    def propertyType(self):
        '''int QDeclarativeProperty.propertyType()'''
        return int()
    def isSignalProperty(self):
        '''bool QDeclarativeProperty.isSignalProperty()'''
        return bool()
    def isProperty(self):
        '''bool QDeclarativeProperty.isProperty()'''
        return bool()
    def isValid(self):
        '''bool QDeclarativeProperty.isValid()'''
        return bool()
    def type(self):
        '''QDeclarativeProperty.Type QDeclarativeProperty.type()'''
        return QDeclarativeProperty.Type()
    def __eq__(self):
        '''QDeclarativeProperty QDeclarativeProperty.__eq__()'''
        return QDeclarativeProperty()


class QDeclarativePropertyMap(QObject):
    """"""
    def __init__(self, parent = None):
        '''void QDeclarativePropertyMap.__init__(QObject parent = None)'''
    valueChanged = pyqtSignal() # void valueChanged(const QStringamp;,const QVariantamp;) - signal
    def __getitem__(self, key):
        '''QVariant QDeclarativePropertyMap.__getitem__(QString key)'''
        return QVariant()
    def contains(self, key):
        '''bool QDeclarativePropertyMap.contains(QString key)'''
        return bool()
    def isEmpty(self):
        '''bool QDeclarativePropertyMap.isEmpty()'''
        return bool()
    def size(self):
        '''int QDeclarativePropertyMap.size()'''
        return int()
    def __len__(self):
        '''None QDeclarativePropertyMap.__len__()'''
        return None()
    def count(self):
        '''int QDeclarativePropertyMap.count()'''
        return int()
    def keys(self):
        '''QStringList QDeclarativePropertyMap.keys()'''
        return QStringList()
    def clear(self, key):
        '''void QDeclarativePropertyMap.clear(QString key)'''
    def insert(self, key, value):
        '''void QDeclarativePropertyMap.insert(QString key, QVariant value)'''
    def value(self, key):
        '''QVariant QDeclarativePropertyMap.value(QString key)'''
        return QVariant()


class QDeclarativePropertyValueSource():
    """"""
    def __init__(self):
        '''void QDeclarativePropertyValueSource.__init__()'''
    def __init__(self):
        '''QDeclarativePropertyValueSource QDeclarativePropertyValueSource.__init__()'''
        return QDeclarativePropertyValueSource()
    def setTarget(self):
        '''abstract QDeclarativeProperty QDeclarativePropertyValueSource.setTarget()'''
        return QDeclarativeProperty()


class QDeclarativeScriptString():
    """"""
    def __init__(self):
        '''void QDeclarativeScriptString.__init__()'''
    def __init__(self):
        '''QDeclarativeScriptString QDeclarativeScriptString.__init__()'''
        return QDeclarativeScriptString()
    def setScript(self):
        '''QString QDeclarativeScriptString.setScript()'''
        return QString()
    def script(self):
        '''QString QDeclarativeScriptString.script()'''
        return QString()
    def setScopeObject(self):
        '''QObject QDeclarativeScriptString.setScopeObject()'''
        return QObject()
    def scopeObject(self):
        '''QObject QDeclarativeScriptString.scopeObject()'''
        return QObject()
    def setContext(self):
        '''QDeclarativeContext QDeclarativeScriptString.setContext()'''
        return QDeclarativeContext()
    def context(self):
        '''QDeclarativeContext QDeclarativeScriptString.context()'''
        return QDeclarativeContext()


class QDeclarativeView(QGraphicsView):
    """"""
    # Enum QDeclarativeView.Status
    Null = 0
    Ready = 0
    Loading = 0
    Error = 0

    # Enum QDeclarativeView.ResizeMode
    SizeViewToRootObject = 0
    SizeRootObjectToView = 0

    def __init__(self, parent = None):
        '''void QDeclarativeView.__init__(QWidget parent = None)'''
    def __init__(self, source, parent = None):
        '''void QDeclarativeView.__init__(QUrl source, QWidget parent = None)'''
    def eventFilter(self, watched, e):
        '''bool QDeclarativeView.eventFilter(QObject watched, QEvent e)'''
        return bool()
    def timerEvent(self):
        '''QTimerEvent QDeclarativeView.timerEvent()'''
        return QTimerEvent()
    def paintEvent(self, event):
        '''void QDeclarativeView.paintEvent(QPaintEvent event)'''
    def resizeEvent(self):
        '''QResizeEvent QDeclarativeView.resizeEvent()'''
        return QResizeEvent()
    statusChanged = pyqtSignal() # void statusChanged(QDeclarativeView::Status) - signal
    sceneResized = pyqtSignal() # void sceneResized(QSize) - signal
    def initialSize(self):
        '''QSize QDeclarativeView.initialSize()'''
        return QSize()
    def sizeHint(self):
        '''QSize QDeclarativeView.sizeHint()'''
        return QSize()
    def errors(self):
        '''list-of-QDeclarativeError QDeclarativeView.errors()'''
        return [QDeclarativeError()]
    def status(self):
        '''QDeclarativeView.Status QDeclarativeView.status()'''
        return QDeclarativeView.Status()
    def setResizeMode(self):
        '''QDeclarativeView.ResizeMode QDeclarativeView.setResizeMode()'''
        return QDeclarativeView.ResizeMode()
    def resizeMode(self):
        '''QDeclarativeView.ResizeMode QDeclarativeView.resizeMode()'''
        return QDeclarativeView.ResizeMode()
    def rootObject(self):
        '''QGraphicsObject QDeclarativeView.rootObject()'''
        return QGraphicsObject()
    def rootContext(self):
        '''QDeclarativeContext QDeclarativeView.rootContext()'''
        return QDeclarativeContext()
    def engine(self):
        '''QDeclarativeEngine QDeclarativeView.engine()'''
        return QDeclarativeEngine()
    def setSource(self):
        '''QUrl QDeclarativeView.setSource()'''
        return QUrl()
    def source(self):
        '''QUrl QDeclarativeView.source()'''
        return QUrl()


class QPyDeclarativePropertyValueSource(QObject, QDeclarativePropertyValueSource):
    """"""
    def __init__(self, parent = None):
        '''void QPyDeclarativePropertyValueSource.__init__(QObject parent = None)'''





# AUTO-GENERATED FILE -- DO NOT EDIT

""" Access to the Unix group database.

Group entries are reported as 4-tuples containing the following fields
from the group database, in order:

  name   - name of the group
  passwd - group password (encrypted); often empty
  gid    - numeric ID of the group
  mem    - list of members

The gid is an integer, name and password are strings.  (Note that most
users are not explicitly listed as members of the groups they are in
according to the password database.  Check both databases to get
complete membership information.) """

__package__ = None

def getgrall():
  """ getgrall() -> list of tuples
  Return a list of all available group entries, in arbitrary order.
  An entry whose name starts with '+' or '-' represents an instruction
  to use YP/NIS and may not be accessible via getgrnam or getgrgid. """
  return ()

def getgrgid(id):
  """ getgrgid(id) -> tuple
  Return the group database entry for the given numeric group ID.  If
  id is not valid, raise KeyError. """
  return ()

def getgrnam(name):
  """ getgrnam(name) -> tuple
  Return the group database entry for the given group name.  If
  name is not valid, raise KeyError. """
  return ()

class struct_group(object):
  """ grp.struct_group: Results from getgr*() routines.
  
  This object may be accessed either as a tuple of
    (gr_name,gr_passwd,gr_gid,gr_mem)
  or via the object attributes as named in the above tuple.
   """

  gr_gid = None
  gr_mem = None
  gr_name = None
  gr_passwd = None
  n_fields = 4
  n_sequence_fields = 4
  n_unnamed_fields = 0




class pyqtSignal():
 def connect(self, targetSignal): pass
 def emit(self, *args): pass
from QtCore import *

from QtWidgets import *

import datetime

class QQuickWidget(QWidget):
    """"""
    # Enum QQuickWidget.Status
    Null = 0
    Ready = 0
    Loading = 0
    Error = 0

    # Enum QQuickWidget.ResizeMode
    SizeViewToRootObject = 0
    SizeRootObjectToView = 0

    def __init__(self, parent = None):
        '''void QQuickWidget.__init__(QWidget parent = None)'''
    def __init__(self, engine, parent):
        '''void QQuickWidget.__init__(QQmlEngine engine, QWidget parent)'''
    def __init__(self, source, parent = None):
        '''void QQuickWidget.__init__(QUrl source, QWidget parent = None)'''
    def quickWindow(self):
        '''QQuickWindow QQuickWidget.quickWindow()'''
        return QQuickWindow()
    def setClearColor(self, color):
        '''void QQuickWidget.setClearColor(QColor color)'''
    def grabFramebuffer(self):
        '''QImage QQuickWidget.grabFramebuffer()'''
        return QImage()
    def dropEvent(self):
        '''QDropEvent QQuickWidget.dropEvent()'''
        return QDropEvent()
    def dragLeaveEvent(self):
        '''QDragLeaveEvent QQuickWidget.dragLeaveEvent()'''
        return QDragLeaveEvent()
    def dragMoveEvent(self):
        '''QDragMoveEvent QQuickWidget.dragMoveEvent()'''
        return QDragMoveEvent()
    def dragEnterEvent(self):
        '''QDragEnterEvent QQuickWidget.dragEnterEvent()'''
        return QDragEnterEvent()
    def focusOutEvent(self, event):
        '''void QQuickWidget.focusOutEvent(QFocusEvent event)'''
    def focusInEvent(self, event):
        '''void QQuickWidget.focusInEvent(QFocusEvent event)'''
    def event(self):
        '''QEvent QQuickWidget.event()'''
        return QEvent()
    def wheelEvent(self):
        '''QWheelEvent QQuickWidget.wheelEvent()'''
        return QWheelEvent()
    def hideEvent(self):
        '''QHideEvent QQuickWidget.hideEvent()'''
        return QHideEvent()
    def showEvent(self):
        '''QShowEvent QQuickWidget.showEvent()'''
        return QShowEvent()
    def mouseDoubleClickEvent(self):
        '''QMouseEvent QQuickWidget.mouseDoubleClickEvent()'''
        return QMouseEvent()
    def mouseMoveEvent(self):
        '''QMouseEvent QQuickWidget.mouseMoveEvent()'''
        return QMouseEvent()
    def mouseReleaseEvent(self):
        '''QMouseEvent QQuickWidget.mouseReleaseEvent()'''
        return QMouseEvent()
    def mousePressEvent(self):
        '''QMouseEvent QQuickWidget.mousePressEvent()'''
        return QMouseEvent()
    def keyReleaseEvent(self):
        '''QKeyEvent QQuickWidget.keyReleaseEvent()'''
        return QKeyEvent()
    def keyPressEvent(self):
        '''QKeyEvent QQuickWidget.keyPressEvent()'''
        return QKeyEvent()
    def timerEvent(self):
        '''QTimerEvent QQuickWidget.timerEvent()'''
        return QTimerEvent()
    def resizeEvent(self):
        '''QResizeEvent QQuickWidget.resizeEvent()'''
        return QResizeEvent()
    sceneGraphError = pyqtSignal() # void sceneGraphError(QQuickWindow::SceneGraphError,const QStringamp;) - signal
    statusChanged = pyqtSignal() # void statusChanged(QQuickWidget::Status) - signal
    def setSource(self):
        '''QUrl QQuickWidget.setSource()'''
        return QUrl()
    def format(self):
        '''QSurfaceFormat QQuickWidget.format()'''
        return QSurfaceFormat()
    def setFormat(self, format):
        '''void QQuickWidget.setFormat(QSurfaceFormat format)'''
    def initialSize(self):
        '''QSize QQuickWidget.initialSize()'''
        return QSize()
    def sizeHint(self):
        '''QSize QQuickWidget.sizeHint()'''
        return QSize()
    def errors(self):
        '''list-of-QQmlError QQuickWidget.errors()'''
        return [QQmlError()]
    def status(self):
        '''QQuickWidget.Status QQuickWidget.status()'''
        return QQuickWidget.Status()
    def setResizeMode(self):
        '''QQuickWidget.ResizeMode QQuickWidget.setResizeMode()'''
        return QQuickWidget.ResizeMode()
    def resizeMode(self):
        '''QQuickWidget.ResizeMode QQuickWidget.resizeMode()'''
        return QQuickWidget.ResizeMode()
    def rootObject(self):
        '''QQuickItem QQuickWidget.rootObject()'''
        return QQuickItem()
    def rootContext(self):
        '''QQmlContext QQuickWidget.rootContext()'''
        return QQmlContext()
    def engine(self):
        '''QQmlEngine QQuickWidget.engine()'''
        return QQmlEngine()
    def source(self):
        '''QUrl QQuickWidget.source()'''
        return QUrl()





class pyqtSignal():
 def connect(self, targetSignal): pass
 def emit(self, *args): pass
from QtCore import *

from QtWidgets import *

import datetime

class QXmlNamespaceSupport():
    """"""
    def __init__(self):
        '''void QXmlNamespaceSupport.__init__()'''
    def reset(self):
        '''void QXmlNamespaceSupport.reset()'''
    def popContext(self):
        '''void QXmlNamespaceSupport.popContext()'''
    def pushContext(self):
        '''void QXmlNamespaceSupport.pushContext()'''
    def prefixes(self):
        '''list-of-str QXmlNamespaceSupport.prefixes()'''
        return [str()]
    def prefixes(self):
        '''str QXmlNamespaceSupport.prefixes()'''
        return str()
    def processName(self):
        '''str QXmlNamespaceSupport.processName()'''
        return str()
    def splitName(self):
        '''str QXmlNamespaceSupport.splitName()'''
        return str()
    def uri(self):
        '''str QXmlNamespaceSupport.uri()'''
        return str()
    def prefix(self):
        '''str QXmlNamespaceSupport.prefix()'''
        return str()
    def setPrefix(self):
        '''str QXmlNamespaceSupport.setPrefix()'''
        return str()


class QXmlAttributes():
    """"""
    def __init__(self):
        '''void QXmlAttributes.__init__()'''
    def __init__(self):
        '''QXmlAttributes QXmlAttributes.__init__()'''
        return QXmlAttributes()
    def __len__(self):
        ''' QXmlAttributes.__len__()'''
        return ()
    def count(self):
        '''int QXmlAttributes.count()'''
        return int()
    def append(self, qName, uri, localPart, value):
        '''void QXmlAttributes.append(str qName, str uri, str localPart, str value)'''
    def clear(self):
        '''void QXmlAttributes.clear()'''
    def value(self, index):
        '''str QXmlAttributes.value(int index)'''
        return str()
    def value(self, qName):
        '''str QXmlAttributes.value(str qName)'''
        return str()
    def value(self, uri, localName):
        '''str QXmlAttributes.value(str uri, str localName)'''
        return str()
    def type(self, index):
        '''str QXmlAttributes.type(int index)'''
        return str()
    def type(self, qName):
        '''str QXmlAttributes.type(str qName)'''
        return str()
    def type(self, uri, localName):
        '''str QXmlAttributes.type(str uri, str localName)'''
        return str()
    def uri(self, index):
        '''str QXmlAttributes.uri(int index)'''
        return str()
    def qName(self, index):
        '''str QXmlAttributes.qName(int index)'''
        return str()
    def localName(self, index):
        '''str QXmlAttributes.localName(int index)'''
        return str()
    def length(self):
        '''int QXmlAttributes.length()'''
        return int()
    def index(self, qName):
        '''int QXmlAttributes.index(str qName)'''
        return int()
    def index(self, uri, localPart):
        '''int QXmlAttributes.index(str uri, str localPart)'''
        return int()


class QXmlInputSource():
    """"""
    EndOfData = None # int - member
    EndOfDocument = None # int - member
    def __init__(self):
        '''void QXmlInputSource.__init__()'''
    def __init__(self, dev):
        '''void QXmlInputSource.__init__(QIODevice dev)'''
    def __init__(self):
        '''QXmlInputSource QXmlInputSource.__init__()'''
        return QXmlInputSource()
    def fromRawData(self, data, beginning = False):
        '''str QXmlInputSource.fromRawData(QByteArray data, bool beginning = False)'''
        return str()
    def reset(self):
        '''void QXmlInputSource.reset()'''
    def next(self):
        '''str QXmlInputSource.next()'''
        return str()
    def data(self):
        '''str QXmlInputSource.data()'''
        return str()
    def fetchData(self):
        '''void QXmlInputSource.fetchData()'''
    def setData(self, dat):
        '''void QXmlInputSource.setData(str dat)'''
    def setData(self, dat):
        '''void QXmlInputSource.setData(QByteArray dat)'''


class QXmlParseException():
    """"""
    def __init__(self, name = str(), column = None, line = None, publicId = str(), systemId = str()):
        '''void QXmlParseException.__init__(str name = str(), int column = -1, int line = -1, str publicId = str(), str systemId = str())'''
    def __init__(self, other):
        '''void QXmlParseException.__init__(QXmlParseException other)'''
    def message(self):
        '''str QXmlParseException.message()'''
        return str()
    def systemId(self):
        '''str QXmlParseException.systemId()'''
        return str()
    def publicId(self):
        '''str QXmlParseException.publicId()'''
        return str()
    def lineNumber(self):
        '''int QXmlParseException.lineNumber()'''
        return int()
    def columnNumber(self):
        '''int QXmlParseException.columnNumber()'''
        return int()


class QXmlReader():
    """"""
    def __init__(self):
        '''void QXmlReader.__init__()'''
    def __init__(self):
        '''QXmlReader QXmlReader.__init__()'''
        return QXmlReader()
    def parse(self, input):
        '''abstract bool QXmlReader.parse(QXmlInputSource input)'''
        return bool()
    def parse(self, input):
        '''abstract bool QXmlReader.parse(QXmlInputSource input)'''
        return bool()
    def declHandler(self):
        '''abstract QXmlDeclHandler QXmlReader.declHandler()'''
        return QXmlDeclHandler()
    def setDeclHandler(self, handler):
        '''abstract void QXmlReader.setDeclHandler(QXmlDeclHandler handler)'''
    def lexicalHandler(self):
        '''abstract QXmlLexicalHandler QXmlReader.lexicalHandler()'''
        return QXmlLexicalHandler()
    def setLexicalHandler(self, handler):
        '''abstract void QXmlReader.setLexicalHandler(QXmlLexicalHandler handler)'''
    def errorHandler(self):
        '''abstract QXmlErrorHandler QXmlReader.errorHandler()'''
        return QXmlErrorHandler()
    def setErrorHandler(self, handler):
        '''abstract void QXmlReader.setErrorHandler(QXmlErrorHandler handler)'''
    def contentHandler(self):
        '''abstract QXmlContentHandler QXmlReader.contentHandler()'''
        return QXmlContentHandler()
    def setContentHandler(self, handler):
        '''abstract void QXmlReader.setContentHandler(QXmlContentHandler handler)'''
    def DTDHandler(self):
        '''abstract QXmlDTDHandler QXmlReader.DTDHandler()'''
        return QXmlDTDHandler()
    def setDTDHandler(self, handler):
        '''abstract void QXmlReader.setDTDHandler(QXmlDTDHandler handler)'''
    def entityResolver(self):
        '''abstract QXmlEntityResolver QXmlReader.entityResolver()'''
        return QXmlEntityResolver()
    def setEntityResolver(self, handler):
        '''abstract void QXmlReader.setEntityResolver(QXmlEntityResolver handler)'''
    def hasProperty(self, name):
        '''abstract bool QXmlReader.hasProperty(str name)'''
        return bool()
    def setProperty(self, name, value):
        '''abstract void QXmlReader.setProperty(str name, sip.voidptr value)'''
    def property(self, name, ok):
        '''abstract sip.voidptr QXmlReader.property(str name, bool ok)'''
        return sip.voidptr()
    def hasFeature(self, name):
        '''abstract bool QXmlReader.hasFeature(str name)'''
        return bool()
    def setFeature(self, name, value):
        '''abstract void QXmlReader.setFeature(str name, bool value)'''
    def feature(self, name, ok):
        '''abstract bool QXmlReader.feature(str name, bool ok)'''
        return bool()


class QXmlSimpleReader(QXmlReader):
    """"""
    def __init__(self):
        '''void QXmlSimpleReader.__init__()'''
    def parseContinue(self):
        '''bool QXmlSimpleReader.parseContinue()'''
        return bool()
    def parse(self, input):
        '''bool QXmlSimpleReader.parse(QXmlInputSource input)'''
        return bool()
    def parse(self, input, incremental):
        '''bool QXmlSimpleReader.parse(QXmlInputSource input, bool incremental)'''
        return bool()
    def declHandler(self):
        '''QXmlDeclHandler QXmlSimpleReader.declHandler()'''
        return QXmlDeclHandler()
    def setDeclHandler(self, handler):
        '''void QXmlSimpleReader.setDeclHandler(QXmlDeclHandler handler)'''
    def lexicalHandler(self):
        '''QXmlLexicalHandler QXmlSimpleReader.lexicalHandler()'''
        return QXmlLexicalHandler()
    def setLexicalHandler(self, handler):
        '''void QXmlSimpleReader.setLexicalHandler(QXmlLexicalHandler handler)'''
    def errorHandler(self):
        '''QXmlErrorHandler QXmlSimpleReader.errorHandler()'''
        return QXmlErrorHandler()
    def setErrorHandler(self, handler):
        '''void QXmlSimpleReader.setErrorHandler(QXmlErrorHandler handler)'''
    def contentHandler(self):
        '''QXmlContentHandler QXmlSimpleReader.contentHandler()'''
        return QXmlContentHandler()
    def setContentHandler(self, handler):
        '''void QXmlSimpleReader.setContentHandler(QXmlContentHandler handler)'''
    def DTDHandler(self):
        '''QXmlDTDHandler QXmlSimpleReader.DTDHandler()'''
        return QXmlDTDHandler()
    def setDTDHandler(self, handler):
        '''void QXmlSimpleReader.setDTDHandler(QXmlDTDHandler handler)'''
    def entityResolver(self):
        '''QXmlEntityResolver QXmlSimpleReader.entityResolver()'''
        return QXmlEntityResolver()
    def setEntityResolver(self, handler):
        '''void QXmlSimpleReader.setEntityResolver(QXmlEntityResolver handler)'''
    def hasProperty(self, name):
        '''bool QXmlSimpleReader.hasProperty(str name)'''
        return bool()
    def setProperty(self, name, value):
        '''void QXmlSimpleReader.setProperty(str name, sip.voidptr value)'''
    def property(self, name, ok):
        '''sip.voidptr QXmlSimpleReader.property(str name, bool ok)'''
        return sip.voidptr()
    def hasFeature(self, name):
        '''bool QXmlSimpleReader.hasFeature(str name)'''
        return bool()
    def setFeature(self, name, value):
        '''void QXmlSimpleReader.setFeature(str name, bool value)'''
    def feature(self, name, ok):
        '''bool QXmlSimpleReader.feature(str name, bool ok)'''
        return bool()


class QXmlLocator():
    """"""
    def __init__(self):
        '''void QXmlLocator.__init__()'''
    def __init__(self):
        '''QXmlLocator QXmlLocator.__init__()'''
        return QXmlLocator()
    def lineNumber(self):
        '''abstract int QXmlLocator.lineNumber()'''
        return int()
    def columnNumber(self):
        '''abstract int QXmlLocator.columnNumber()'''
        return int()


class QXmlContentHandler():
    """"""
    def __init__(self):
        '''void QXmlContentHandler.__init__()'''
    def __init__(self):
        '''QXmlContentHandler QXmlContentHandler.__init__()'''
        return QXmlContentHandler()
    def errorString(self):
        '''abstract str QXmlContentHandler.errorString()'''
        return str()
    def skippedEntity(self, name):
        '''abstract bool QXmlContentHandler.skippedEntity(str name)'''
        return bool()
    def processingInstruction(self, target, data):
        '''abstract bool QXmlContentHandler.processingInstruction(str target, str data)'''
        return bool()
    def ignorableWhitespace(self, ch):
        '''abstract bool QXmlContentHandler.ignorableWhitespace(str ch)'''
        return bool()
    def characters(self, ch):
        '''abstract bool QXmlContentHandler.characters(str ch)'''
        return bool()
    def endElement(self, namespaceURI, localName, qName):
        '''abstract bool QXmlContentHandler.endElement(str namespaceURI, str localName, str qName)'''
        return bool()
    def startElement(self, namespaceURI, localName, qName, atts):
        '''abstract bool QXmlContentHandler.startElement(str namespaceURI, str localName, str qName, QXmlAttributes atts)'''
        return bool()
    def endPrefixMapping(self, prefix):
        '''abstract bool QXmlContentHandler.endPrefixMapping(str prefix)'''
        return bool()
    def startPrefixMapping(self, prefix, uri):
        '''abstract bool QXmlContentHandler.startPrefixMapping(str prefix, str uri)'''
        return bool()
    def endDocument(self):
        '''abstract bool QXmlContentHandler.endDocument()'''
        return bool()
    def startDocument(self):
        '''abstract bool QXmlContentHandler.startDocument()'''
        return bool()
    def setDocumentLocator(self, locator):
        '''abstract void QXmlContentHandler.setDocumentLocator(QXmlLocator locator)'''


class QXmlErrorHandler():
    """"""
    def __init__(self):
        '''void QXmlErrorHandler.__init__()'''
    def __init__(self):
        '''QXmlErrorHandler QXmlErrorHandler.__init__()'''
        return QXmlErrorHandler()
    def errorString(self):
        '''abstract str QXmlErrorHandler.errorString()'''
        return str()
    def fatalError(self, exception):
        '''abstract bool QXmlErrorHandler.fatalError(QXmlParseException exception)'''
        return bool()
    def error(self, exception):
        '''abstract bool QXmlErrorHandler.error(QXmlParseException exception)'''
        return bool()
    def warning(self, exception):
        '''abstract bool QXmlErrorHandler.warning(QXmlParseException exception)'''
        return bool()


class QXmlDTDHandler():
    """"""
    def __init__(self):
        '''void QXmlDTDHandler.__init__()'''
    def __init__(self):
        '''QXmlDTDHandler QXmlDTDHandler.__init__()'''
        return QXmlDTDHandler()
    def errorString(self):
        '''abstract str QXmlDTDHandler.errorString()'''
        return str()
    def unparsedEntityDecl(self, name, publicId, systemId, notationName):
        '''abstract bool QXmlDTDHandler.unparsedEntityDecl(str name, str publicId, str systemId, str notationName)'''
        return bool()
    def notationDecl(self, name, publicId, systemId):
        '''abstract bool QXmlDTDHandler.notationDecl(str name, str publicId, str systemId)'''
        return bool()


class QXmlEntityResolver():
    """"""
    def __init__(self):
        '''void QXmlEntityResolver.__init__()'''
    def __init__(self):
        '''QXmlEntityResolver QXmlEntityResolver.__init__()'''
        return QXmlEntityResolver()
    def errorString(self):
        '''abstract str QXmlEntityResolver.errorString()'''
        return str()
    def resolveEntity(self, publicId, systemId, ret):
        '''abstract bool QXmlEntityResolver.resolveEntity(str publicId, str systemId, QXmlInputSource ret)'''
        return bool()


class QXmlLexicalHandler():
    """"""
    def __init__(self):
        '''void QXmlLexicalHandler.__init__()'''
    def __init__(self):
        '''QXmlLexicalHandler QXmlLexicalHandler.__init__()'''
        return QXmlLexicalHandler()
    def errorString(self):
        '''abstract str QXmlLexicalHandler.errorString()'''
        return str()
    def comment(self, ch):
        '''abstract bool QXmlLexicalHandler.comment(str ch)'''
        return bool()
    def endCDATA(self):
        '''abstract bool QXmlLexicalHandler.endCDATA()'''
        return bool()
    def startCDATA(self):
        '''abstract bool QXmlLexicalHandler.startCDATA()'''
        return bool()
    def endEntity(self, name):
        '''abstract bool QXmlLexicalHandler.endEntity(str name)'''
        return bool()
    def startEntity(self, name):
        '''abstract bool QXmlLexicalHandler.startEntity(str name)'''
        return bool()
    def endDTD(self):
        '''abstract bool QXmlLexicalHandler.endDTD()'''
        return bool()
    def startDTD(self, name, publicId, systemId):
        '''abstract bool QXmlLexicalHandler.startDTD(str name, str publicId, str systemId)'''
        return bool()


class QXmlDeclHandler():
    """"""
    def __init__(self):
        '''void QXmlDeclHandler.__init__()'''
    def __init__(self):
        '''QXmlDeclHandler QXmlDeclHandler.__init__()'''
        return QXmlDeclHandler()
    def errorString(self):
        '''abstract str QXmlDeclHandler.errorString()'''
        return str()
    def externalEntityDecl(self, name, publicId, systemId):
        '''abstract bool QXmlDeclHandler.externalEntityDecl(str name, str publicId, str systemId)'''
        return bool()
    def internalEntityDecl(self, name, value):
        '''abstract bool QXmlDeclHandler.internalEntityDecl(str name, str value)'''
        return bool()
    def attributeDecl(self, eName, aName, type, valueDefault, value):
        '''abstract bool QXmlDeclHandler.attributeDecl(str eName, str aName, str type, str valueDefault, str value)'''
        return bool()


class QXmlDefaultHandler(QXmlContentHandler, QXmlErrorHandler, QXmlDTDHandler, QXmlEntityResolver, QXmlLexicalHandler, QXmlDeclHandler):
    """"""
    def __init__(self):
        '''void QXmlDefaultHandler.__init__()'''
    def errorString(self):
        '''str QXmlDefaultHandler.errorString()'''
        return str()
    def externalEntityDecl(self, name, publicId, systemId):
        '''bool QXmlDefaultHandler.externalEntityDecl(str name, str publicId, str systemId)'''
        return bool()
    def internalEntityDecl(self, name, value):
        '''bool QXmlDefaultHandler.internalEntityDecl(str name, str value)'''
        return bool()
    def attributeDecl(self, eName, aName, type, valueDefault, value):
        '''bool QXmlDefaultHandler.attributeDecl(str eName, str aName, str type, str valueDefault, str value)'''
        return bool()
    def comment(self, ch):
        '''bool QXmlDefaultHandler.comment(str ch)'''
        return bool()
    def endCDATA(self):
        '''bool QXmlDefaultHandler.endCDATA()'''
        return bool()
    def startCDATA(self):
        '''bool QXmlDefaultHandler.startCDATA()'''
        return bool()
    def endEntity(self, name):
        '''bool QXmlDefaultHandler.endEntity(str name)'''
        return bool()
    def startEntity(self, name):
        '''bool QXmlDefaultHandler.startEntity(str name)'''
        return bool()
    def endDTD(self):
        '''bool QXmlDefaultHandler.endDTD()'''
        return bool()
    def startDTD(self, name, publicId, systemId):
        '''bool QXmlDefaultHandler.startDTD(str name, str publicId, str systemId)'''
        return bool()
    def resolveEntity(self, publicId, systemId, ret):
        '''bool QXmlDefaultHandler.resolveEntity(str publicId, str systemId, QXmlInputSource ret)'''
        return bool()
    def unparsedEntityDecl(self, name, publicId, systemId, notationName):
        '''bool QXmlDefaultHandler.unparsedEntityDecl(str name, str publicId, str systemId, str notationName)'''
        return bool()
    def notationDecl(self, name, publicId, systemId):
        '''bool QXmlDefaultHandler.notationDecl(str name, str publicId, str systemId)'''
        return bool()
    def fatalError(self, exception):
        '''bool QXmlDefaultHandler.fatalError(QXmlParseException exception)'''
        return bool()
    def error(self, exception):
        '''bool QXmlDefaultHandler.error(QXmlParseException exception)'''
        return bool()
    def warning(self, exception):
        '''bool QXmlDefaultHandler.warning(QXmlParseException exception)'''
        return bool()
    def skippedEntity(self, name):
        '''bool QXmlDefaultHandler.skippedEntity(str name)'''
        return bool()
    def processingInstruction(self, target, data):
        '''bool QXmlDefaultHandler.processingInstruction(str target, str data)'''
        return bool()
    def ignorableWhitespace(self, ch):
        '''bool QXmlDefaultHandler.ignorableWhitespace(str ch)'''
        return bool()
    def characters(self, ch):
        '''bool QXmlDefaultHandler.characters(str ch)'''
        return bool()
    def endElement(self, namespaceURI, localName, qName):
        '''bool QXmlDefaultHandler.endElement(str namespaceURI, str localName, str qName)'''
        return bool()
    def startElement(self, namespaceURI, localName, qName, atts):
        '''bool QXmlDefaultHandler.startElement(str namespaceURI, str localName, str qName, QXmlAttributes atts)'''
        return bool()
    def endPrefixMapping(self, prefix):
        '''bool QXmlDefaultHandler.endPrefixMapping(str prefix)'''
        return bool()
    def startPrefixMapping(self, prefix, uri):
        '''bool QXmlDefaultHandler.startPrefixMapping(str prefix, str uri)'''
        return bool()
    def endDocument(self):
        '''bool QXmlDefaultHandler.endDocument()'''
        return bool()
    def startDocument(self):
        '''bool QXmlDefaultHandler.startDocument()'''
        return bool()
    def setDocumentLocator(self, locator):
        '''void QXmlDefaultHandler.setDocumentLocator(QXmlLocator locator)'''


class QDomImplementation():
    """"""
    # Enum QDomImplementation.InvalidDataPolicy
    AcceptInvalidChars = 0
    DropInvalidChars = 0
    ReturnNullNode = 0

    def __init__(self):
        '''void QDomImplementation.__init__()'''
    def __init__(self):
        '''QDomImplementation QDomImplementation.__init__()'''
        return QDomImplementation()
    def isNull(self):
        '''bool QDomImplementation.isNull()'''
        return bool()
    def setInvalidDataPolicy(self, policy):
        '''static void QDomImplementation.setInvalidDataPolicy(QDomImplementation.InvalidDataPolicy policy)'''
    def invalidDataPolicy(self):
        '''static QDomImplementation.InvalidDataPolicy QDomImplementation.invalidDataPolicy()'''
        return QDomImplementation.InvalidDataPolicy()
    def createDocument(self, nsURI, qName, doctype):
        '''QDomDocument QDomImplementation.createDocument(str nsURI, str qName, QDomDocumentType doctype)'''
        return QDomDocument()
    def createDocumentType(self, qName, publicId, systemId):
        '''QDomDocumentType QDomImplementation.createDocumentType(str qName, str publicId, str systemId)'''
        return QDomDocumentType()
    def hasFeature(self, feature, version):
        '''bool QDomImplementation.hasFeature(str feature, str version)'''
        return bool()
    def __ne__(self):
        '''QDomImplementation QDomImplementation.__ne__()'''
        return QDomImplementation()
    def __eq__(self):
        '''QDomImplementation QDomImplementation.__eq__()'''
        return QDomImplementation()


class QDomNode():
    """"""
    # Enum QDomNode.EncodingPolicy
    EncodingFromDocument = 0
    EncodingFromTextStream = 0

    # Enum QDomNode.NodeType
    ElementNode = 0
    AttributeNode = 0
    TextNode = 0
    CDATASectionNode = 0
    EntityReferenceNode = 0
    EntityNode = 0
    ProcessingInstructionNode = 0
    CommentNode = 0
    DocumentNode = 0
    DocumentTypeNode = 0
    DocumentFragmentNode = 0
    NotationNode = 0
    BaseNode = 0
    CharacterDataNode = 0

    def __init__(self):
        '''void QDomNode.__init__()'''
    def __init__(self):
        '''QDomNode QDomNode.__init__()'''
        return QDomNode()
    def columnNumber(self):
        '''int QDomNode.columnNumber()'''
        return int()
    def lineNumber(self):
        '''int QDomNode.lineNumber()'''
        return int()
    def nextSiblingElement(self, taName = str()):
        '''QDomElement QDomNode.nextSiblingElement(str taName = str())'''
        return QDomElement()
    def previousSiblingElement(self, tagName = str()):
        '''QDomElement QDomNode.previousSiblingElement(str tagName = str())'''
        return QDomElement()
    def lastChildElement(self, tagName = str()):
        '''QDomElement QDomNode.lastChildElement(str tagName = str())'''
        return QDomElement()
    def firstChildElement(self, tagName = str()):
        '''QDomElement QDomNode.firstChildElement(str tagName = str())'''
        return QDomElement()
    def save(self):
        '''QDomNode.EncodingPolicy QDomNode.save()'''
        return QDomNode.EncodingPolicy()
    def toComment(self):
        '''QDomComment QDomNode.toComment()'''
        return QDomComment()
    def toCharacterData(self):
        '''QDomCharacterData QDomNode.toCharacterData()'''
        return QDomCharacterData()
    def toProcessingInstruction(self):
        '''QDomProcessingInstruction QDomNode.toProcessingInstruction()'''
        return QDomProcessingInstruction()
    def toNotation(self):
        '''QDomNotation QDomNode.toNotation()'''
        return QDomNotation()
    def toEntity(self):
        '''QDomEntity QDomNode.toEntity()'''
        return QDomEntity()
    def toText(self):
        '''QDomText QDomNode.toText()'''
        return QDomText()
    def toEntityReference(self):
        '''QDomEntityReference QDomNode.toEntityReference()'''
        return QDomEntityReference()
    def toElement(self):
        '''QDomElement QDomNode.toElement()'''
        return QDomElement()
    def toDocumentType(self):
        '''QDomDocumentType QDomNode.toDocumentType()'''
        return QDomDocumentType()
    def toDocument(self):
        '''QDomDocument QDomNode.toDocument()'''
        return QDomDocument()
    def toDocumentFragment(self):
        '''QDomDocumentFragment QDomNode.toDocumentFragment()'''
        return QDomDocumentFragment()
    def toCDATASection(self):
        '''QDomCDATASection QDomNode.toCDATASection()'''
        return QDomCDATASection()
    def toAttr(self):
        '''QDomAttr QDomNode.toAttr()'''
        return QDomAttr()
    def clear(self):
        '''void QDomNode.clear()'''
    def isNull(self):
        '''bool QDomNode.isNull()'''
        return bool()
    def namedItem(self, name):
        '''QDomNode QDomNode.namedItem(str name)'''
        return QDomNode()
    def isComment(self):
        '''bool QDomNode.isComment()'''
        return bool()
    def isCharacterData(self):
        '''bool QDomNode.isCharacterData()'''
        return bool()
    def isProcessingInstruction(self):
        '''bool QDomNode.isProcessingInstruction()'''
        return bool()
    def isNotation(self):
        '''bool QDomNode.isNotation()'''
        return bool()
    def isEntity(self):
        '''bool QDomNode.isEntity()'''
        return bool()
    def isText(self):
        '''bool QDomNode.isText()'''
        return bool()
    def isEntityReference(self):
        '''bool QDomNode.isEntityReference()'''
        return bool()
    def isElement(self):
        '''bool QDomNode.isElement()'''
        return bool()
    def isDocumentType(self):
        '''bool QDomNode.isDocumentType()'''
        return bool()
    def isDocument(self):
        '''bool QDomNode.isDocument()'''
        return bool()
    def isDocumentFragment(self):
        '''bool QDomNode.isDocumentFragment()'''
        return bool()
    def isCDATASection(self):
        '''bool QDomNode.isCDATASection()'''
        return bool()
    def isAttr(self):
        '''bool QDomNode.isAttr()'''
        return bool()
    def setPrefix(self, pre):
        '''void QDomNode.setPrefix(str pre)'''
    def prefix(self):
        '''str QDomNode.prefix()'''
        return str()
    def setNodeValue(self):
        '''str QDomNode.setNodeValue()'''
        return str()
    def nodeValue(self):
        '''str QDomNode.nodeValue()'''
        return str()
    def hasAttributes(self):
        '''bool QDomNode.hasAttributes()'''
        return bool()
    def localName(self):
        '''str QDomNode.localName()'''
        return str()
    def namespaceURI(self):
        '''str QDomNode.namespaceURI()'''
        return str()
    def ownerDocument(self):
        '''QDomDocument QDomNode.ownerDocument()'''
        return QDomDocument()
    def attributes(self):
        '''QDomNamedNodeMap QDomNode.attributes()'''
        return QDomNamedNodeMap()
    def nextSibling(self):
        '''QDomNode QDomNode.nextSibling()'''
        return QDomNode()
    def previousSibling(self):
        '''QDomNode QDomNode.previousSibling()'''
        return QDomNode()
    def lastChild(self):
        '''QDomNode QDomNode.lastChild()'''
        return QDomNode()
    def firstChild(self):
        '''QDomNode QDomNode.firstChild()'''
        return QDomNode()
    def childNodes(self):
        '''QDomNodeList QDomNode.childNodes()'''
        return QDomNodeList()
    def parentNode(self):
        '''QDomNode QDomNode.parentNode()'''
        return QDomNode()
    def nodeType(self):
        '''QDomNode.NodeType QDomNode.nodeType()'''
        return QDomNode.NodeType()
    def nodeName(self):
        '''str QDomNode.nodeName()'''
        return str()
    def isSupported(self, feature, version):
        '''bool QDomNode.isSupported(str feature, str version)'''
        return bool()
    def normalize(self):
        '''void QDomNode.normalize()'''
    def cloneNode(self, deep = True):
        '''QDomNode QDomNode.cloneNode(bool deep = True)'''
        return QDomNode()
    def hasChildNodes(self):
        '''bool QDomNode.hasChildNodes()'''
        return bool()
    def appendChild(self, newChild):
        '''QDomNode QDomNode.appendChild(QDomNode newChild)'''
        return QDomNode()
    def removeChild(self, oldChild):
        '''QDomNode QDomNode.removeChild(QDomNode oldChild)'''
        return QDomNode()
    def replaceChild(self, newChild, oldChild):
        '''QDomNode QDomNode.replaceChild(QDomNode newChild, QDomNode oldChild)'''
        return QDomNode()
    def insertAfter(self, newChild, refChild):
        '''QDomNode QDomNode.insertAfter(QDomNode newChild, QDomNode refChild)'''
        return QDomNode()
    def insertBefore(self, newChild, refChild):
        '''QDomNode QDomNode.insertBefore(QDomNode newChild, QDomNode refChild)'''
        return QDomNode()
    def __ne__(self):
        '''QDomNode QDomNode.__ne__()'''
        return QDomNode()
    def __eq__(self):
        '''QDomNode QDomNode.__eq__()'''
        return QDomNode()


class QDomNodeList():
    """"""
    def __init__(self):
        '''void QDomNodeList.__init__()'''
    def __init__(self):
        '''QDomNodeList QDomNodeList.__init__()'''
        return QDomNodeList()
    def isEmpty(self):
        '''bool QDomNodeList.isEmpty()'''
        return bool()
    def size(self):
        '''int QDomNodeList.size()'''
        return int()
    def __len__(self):
        ''' QDomNodeList.__len__()'''
        return ()
    def count(self):
        '''int QDomNodeList.count()'''
        return int()
    def length(self):
        '''int QDomNodeList.length()'''
        return int()
    def at(self, index):
        '''QDomNode QDomNodeList.at(int index)'''
        return QDomNode()
    def item(self, index):
        '''QDomNode QDomNodeList.item(int index)'''
        return QDomNode()
    def __ne__(self):
        '''QDomNodeList QDomNodeList.__ne__()'''
        return QDomNodeList()
    def __eq__(self):
        '''QDomNodeList QDomNodeList.__eq__()'''
        return QDomNodeList()


class QDomDocumentType(QDomNode):
    """"""
    def __init__(self):
        '''void QDomDocumentType.__init__()'''
    def __init__(self, x):
        '''void QDomDocumentType.__init__(QDomDocumentType x)'''
    def nodeType(self):
        '''QDomNode.NodeType QDomDocumentType.nodeType()'''
        return QDomNode.NodeType()
    def internalSubset(self):
        '''str QDomDocumentType.internalSubset()'''
        return str()
    def systemId(self):
        '''str QDomDocumentType.systemId()'''
        return str()
    def publicId(self):
        '''str QDomDocumentType.publicId()'''
        return str()
    def notations(self):
        '''QDomNamedNodeMap QDomDocumentType.notations()'''
        return QDomNamedNodeMap()
    def entities(self):
        '''QDomNamedNodeMap QDomDocumentType.entities()'''
        return QDomNamedNodeMap()
    def name(self):
        '''str QDomDocumentType.name()'''
        return str()


class QDomDocument(QDomNode):
    """"""
    def __init__(self):
        '''void QDomDocument.__init__()'''
    def __init__(self, name):
        '''void QDomDocument.__init__(str name)'''
    def __init__(self, doctype):
        '''void QDomDocument.__init__(QDomDocumentType doctype)'''
    def __init__(self, x):
        '''void QDomDocument.__init__(QDomDocument x)'''
    def toByteArray(self, indent = 1):
        '''QByteArray QDomDocument.toByteArray(int indent = 1)'''
        return QByteArray()
    def toString(self, indent = 1):
        '''str QDomDocument.toString(int indent = 1)'''
        return str()
    def setContent(self, text, namespaceProcessing, errorMsg, errorLine, errorColumn):
        '''bool QDomDocument.setContent(QByteArray text, bool namespaceProcessing, str errorMsg, int errorLine, int errorColumn)'''
        return bool()
    def setContent(self, text, namespaceProcessing, errorMsg, errorLine, errorColumn):
        '''bool QDomDocument.setContent(str text, bool namespaceProcessing, str errorMsg, int errorLine, int errorColumn)'''
        return bool()
    def setContent(self, dev, namespaceProcessing, errorMsg, errorLine, errorColumn):
        '''bool QDomDocument.setContent(QIODevice dev, bool namespaceProcessing, str errorMsg, int errorLine, int errorColumn)'''
        return bool()
    def setContent(self, source, namespaceProcessing, errorMsg, errorLine, errorColumn):
        '''bool QDomDocument.setContent(QXmlInputSource source, bool namespaceProcessing, str errorMsg, int errorLine, int errorColumn)'''
        return bool()
    def setContent(self, text, errorMsg, errorLine, errorColumn):
        '''bool QDomDocument.setContent(QByteArray text, str errorMsg, int errorLine, int errorColumn)'''
        return bool()
    def setContent(self, text, errorMsg, errorLine, errorColumn):
        '''bool QDomDocument.setContent(str text, str errorMsg, int errorLine, int errorColumn)'''
        return bool()
    def setContent(self, dev, errorMsg, errorLine, errorColumn):
        '''bool QDomDocument.setContent(QIODevice dev, str errorMsg, int errorLine, int errorColumn)'''
        return bool()
    def setContent(self, source, reader, errorMsg, errorLine, errorColumn):
        '''bool QDomDocument.setContent(QXmlInputSource source, QXmlReader reader, str errorMsg, int errorLine, int errorColumn)'''
        return bool()
    def nodeType(self):
        '''QDomNode.NodeType QDomDocument.nodeType()'''
        return QDomNode.NodeType()
    def documentElement(self):
        '''QDomElement QDomDocument.documentElement()'''
        return QDomElement()
    def implementation(self):
        '''QDomImplementation QDomDocument.implementation()'''
        return QDomImplementation()
    def doctype(self):
        '''QDomDocumentType QDomDocument.doctype()'''
        return QDomDocumentType()
    def elementById(self, elementId):
        '''QDomElement QDomDocument.elementById(str elementId)'''
        return QDomElement()
    def elementsByTagNameNS(self, nsURI, localName):
        '''QDomNodeList QDomDocument.elementsByTagNameNS(str nsURI, str localName)'''
        return QDomNodeList()
    def createAttributeNS(self, nsURI, qName):
        '''QDomAttr QDomDocument.createAttributeNS(str nsURI, str qName)'''
        return QDomAttr()
    def createElementNS(self, nsURI, qName):
        '''QDomElement QDomDocument.createElementNS(str nsURI, str qName)'''
        return QDomElement()
    def importNode(self, importedNode, deep):
        '''QDomNode QDomDocument.importNode(QDomNode importedNode, bool deep)'''
        return QDomNode()
    def elementsByTagName(self, tagname):
        '''QDomNodeList QDomDocument.elementsByTagName(str tagname)'''
        return QDomNodeList()
    def createEntityReference(self, name):
        '''QDomEntityReference QDomDocument.createEntityReference(str name)'''
        return QDomEntityReference()
    def createAttribute(self, name):
        '''QDomAttr QDomDocument.createAttribute(str name)'''
        return QDomAttr()
    def createProcessingInstruction(self, target, data):
        '''QDomProcessingInstruction QDomDocument.createProcessingInstruction(str target, str data)'''
        return QDomProcessingInstruction()
    def createCDATASection(self, data):
        '''QDomCDATASection QDomDocument.createCDATASection(str data)'''
        return QDomCDATASection()
    def createComment(self, data):
        '''QDomComment QDomDocument.createComment(str data)'''
        return QDomComment()
    def createTextNode(self, data):
        '''QDomText QDomDocument.createTextNode(str data)'''
        return QDomText()
    def createDocumentFragment(self):
        '''QDomDocumentFragment QDomDocument.createDocumentFragment()'''
        return QDomDocumentFragment()
    def createElement(self, tagName):
        '''QDomElement QDomDocument.createElement(str tagName)'''
        return QDomElement()


class QDomNamedNodeMap():
    """"""
    def __init__(self):
        '''void QDomNamedNodeMap.__init__()'''
    def __init__(self):
        '''QDomNamedNodeMap QDomNamedNodeMap.__init__()'''
        return QDomNamedNodeMap()
    def contains(self, name):
        '''bool QDomNamedNodeMap.contains(str name)'''
        return bool()
    def isEmpty(self):
        '''bool QDomNamedNodeMap.isEmpty()'''
        return bool()
    def size(self):
        '''int QDomNamedNodeMap.size()'''
        return int()
    def __len__(self):
        ''' QDomNamedNodeMap.__len__()'''
        return ()
    def count(self):
        '''int QDomNamedNodeMap.count()'''
        return int()
    def length(self):
        '''int QDomNamedNodeMap.length()'''
        return int()
    def removeNamedItemNS(self, nsURI, localName):
        '''QDomNode QDomNamedNodeMap.removeNamedItemNS(str nsURI, str localName)'''
        return QDomNode()
    def setNamedItemNS(self, newNode):
        '''QDomNode QDomNamedNodeMap.setNamedItemNS(QDomNode newNode)'''
        return QDomNode()
    def namedItemNS(self, nsURI, localName):
        '''QDomNode QDomNamedNodeMap.namedItemNS(str nsURI, str localName)'''
        return QDomNode()
    def item(self, index):
        '''QDomNode QDomNamedNodeMap.item(int index)'''
        return QDomNode()
    def removeNamedItem(self, name):
        '''QDomNode QDomNamedNodeMap.removeNamedItem(str name)'''
        return QDomNode()
    def setNamedItem(self, newNode):
        '''QDomNode QDomNamedNodeMap.setNamedItem(QDomNode newNode)'''
        return QDomNode()
    def namedItem(self, name):
        '''QDomNode QDomNamedNodeMap.namedItem(str name)'''
        return QDomNode()
    def __ne__(self):
        '''QDomNamedNodeMap QDomNamedNodeMap.__ne__()'''
        return QDomNamedNodeMap()
    def __eq__(self):
        '''QDomNamedNodeMap QDomNamedNodeMap.__eq__()'''
        return QDomNamedNodeMap()


class QDomDocumentFragment(QDomNode):
    """"""
    def __init__(self):
        '''void QDomDocumentFragment.__init__()'''
    def __init__(self, x):
        '''void QDomDocumentFragment.__init__(QDomDocumentFragment x)'''
    def nodeType(self):
        '''QDomNode.NodeType QDomDocumentFragment.nodeType()'''
        return QDomNode.NodeType()


class QDomCharacterData(QDomNode):
    """"""
    def __init__(self):
        '''void QDomCharacterData.__init__()'''
    def __init__(self, x):
        '''void QDomCharacterData.__init__(QDomCharacterData x)'''
    def nodeType(self):
        '''QDomNode.NodeType QDomCharacterData.nodeType()'''
        return QDomNode.NodeType()
    def setData(self):
        '''str QDomCharacterData.setData()'''
        return str()
    def data(self):
        '''str QDomCharacterData.data()'''
        return str()
    def length(self):
        '''int QDomCharacterData.length()'''
        return int()
    def replaceData(self, offset, count, arg):
        '''void QDomCharacterData.replaceData(int offset, int count, str arg)'''
    def deleteData(self, offset, count):
        '''void QDomCharacterData.deleteData(int offset, int count)'''
    def insertData(self, offset, arg):
        '''void QDomCharacterData.insertData(int offset, str arg)'''
    def appendData(self, arg):
        '''void QDomCharacterData.appendData(str arg)'''
    def substringData(self, offset, count):
        '''str QDomCharacterData.substringData(int offset, int count)'''
        return str()


class QDomAttr(QDomNode):
    """"""
    def __init__(self):
        '''void QDomAttr.__init__()'''
    def __init__(self, x):
        '''void QDomAttr.__init__(QDomAttr x)'''
    def nodeType(self):
        '''QDomNode.NodeType QDomAttr.nodeType()'''
        return QDomNode.NodeType()
    def setValue(self):
        '''str QDomAttr.setValue()'''
        return str()
    def value(self):
        '''str QDomAttr.value()'''
        return str()
    def ownerElement(self):
        '''QDomElement QDomAttr.ownerElement()'''
        return QDomElement()
    def specified(self):
        '''bool QDomAttr.specified()'''
        return bool()
    def name(self):
        '''str QDomAttr.name()'''
        return str()


class QDomElement(QDomNode):
    """"""
    def __init__(self):
        '''void QDomElement.__init__()'''
    def __init__(self, x):
        '''void QDomElement.__init__(QDomElement x)'''
    def text(self):
        '''str QDomElement.text()'''
        return str()
    def nodeType(self):
        '''QDomNode.NodeType QDomElement.nodeType()'''
        return QDomNode.NodeType()
    def attributes(self):
        '''QDomNamedNodeMap QDomElement.attributes()'''
        return QDomNamedNodeMap()
    def setTagName(self, name):
        '''void QDomElement.setTagName(str name)'''
    def tagName(self):
        '''str QDomElement.tagName()'''
        return str()
    def hasAttributeNS(self, nsURI, localName):
        '''bool QDomElement.hasAttributeNS(str nsURI, str localName)'''
        return bool()
    def elementsByTagNameNS(self, nsURI, localName):
        '''QDomNodeList QDomElement.elementsByTagNameNS(str nsURI, str localName)'''
        return QDomNodeList()
    def setAttributeNodeNS(self, newAttr):
        '''QDomAttr QDomElement.setAttributeNodeNS(QDomAttr newAttr)'''
        return QDomAttr()
    def attributeNodeNS(self, nsURI, localName):
        '''QDomAttr QDomElement.attributeNodeNS(str nsURI, str localName)'''
        return QDomAttr()
    def removeAttributeNS(self, nsURI, localName):
        '''void QDomElement.removeAttributeNS(str nsURI, str localName)'''
    def setAttributeNS(self, nsURI, qName, value):
        '''void QDomElement.setAttributeNS(str nsURI, str qName, str value)'''
    def setAttributeNS(self, nsURI, qName, value):
        '''void QDomElement.setAttributeNS(str nsURI, str qName, int value)'''
    def setAttributeNS(self, nsURI, qName, value):
        '''void QDomElement.setAttributeNS(str nsURI, str qName, int value)'''
    def setAttributeNS(self, nsURI, qName, value):
        '''void QDomElement.setAttributeNS(str nsURI, str qName, float value)'''
    def setAttributeNS(self, nsURI, qName, value):
        '''void QDomElement.setAttributeNS(str nsURI, str qName, int value)'''
    def attributeNS(self, nsURI, localName, defaultValue = str()):
        '''str QDomElement.attributeNS(str nsURI, str localName, str defaultValue = str())'''
        return str()
    def hasAttribute(self, name):
        '''bool QDomElement.hasAttribute(str name)'''
        return bool()
    def elementsByTagName(self, tagname):
        '''QDomNodeList QDomElement.elementsByTagName(str tagname)'''
        return QDomNodeList()
    def removeAttributeNode(self, oldAttr):
        '''QDomAttr QDomElement.removeAttributeNode(QDomAttr oldAttr)'''
        return QDomAttr()
    def setAttributeNode(self, newAttr):
        '''QDomAttr QDomElement.setAttributeNode(QDomAttr newAttr)'''
        return QDomAttr()
    def attributeNode(self, name):
        '''QDomAttr QDomElement.attributeNode(str name)'''
        return QDomAttr()
    def removeAttribute(self, name):
        '''void QDomElement.removeAttribute(str name)'''
    def setAttribute(self, name, value):
        '''void QDomElement.setAttribute(str name, str value)'''
    def setAttribute(self, name, value):
        '''void QDomElement.setAttribute(str name, int value)'''
    def setAttribute(self, name, value):
        '''void QDomElement.setAttribute(str name, int value)'''
    def setAttribute(self, name, value):
        '''void QDomElement.setAttribute(str name, float value)'''
    def setAttribute(self, name, value):
        '''void QDomElement.setAttribute(str name, int value)'''
    def attribute(self, name, defaultValue = str()):
        '''str QDomElement.attribute(str name, str defaultValue = str())'''
        return str()


class QDomText(QDomCharacterData):
    """"""
    def __init__(self):
        '''void QDomText.__init__()'''
    def __init__(self, x):
        '''void QDomText.__init__(QDomText x)'''
    def nodeType(self):
        '''QDomNode.NodeType QDomText.nodeType()'''
        return QDomNode.NodeType()
    def splitText(self, offset):
        '''QDomText QDomText.splitText(int offset)'''
        return QDomText()


class QDomComment(QDomCharacterData):
    """"""
    def __init__(self):
        '''void QDomComment.__init__()'''
    def __init__(self, x):
        '''void QDomComment.__init__(QDomComment x)'''
    def nodeType(self):
        '''QDomNode.NodeType QDomComment.nodeType()'''
        return QDomNode.NodeType()


class QDomCDATASection(QDomText):
    """"""
    def __init__(self):
        '''void QDomCDATASection.__init__()'''
    def __init__(self, x):
        '''void QDomCDATASection.__init__(QDomCDATASection x)'''
    def nodeType(self):
        '''QDomNode.NodeType QDomCDATASection.nodeType()'''
        return QDomNode.NodeType()


class QDomNotation(QDomNode):
    """"""
    def __init__(self):
        '''void QDomNotation.__init__()'''
    def __init__(self, x):
        '''void QDomNotation.__init__(QDomNotation x)'''
    def nodeType(self):
        '''QDomNode.NodeType QDomNotation.nodeType()'''
        return QDomNode.NodeType()
    def systemId(self):
        '''str QDomNotation.systemId()'''
        return str()
    def publicId(self):
        '''str QDomNotation.publicId()'''
        return str()


class QDomEntity(QDomNode):
    """"""
    def __init__(self):
        '''void QDomEntity.__init__()'''
    def __init__(self, x):
        '''void QDomEntity.__init__(QDomEntity x)'''
    def nodeType(self):
        '''QDomNode.NodeType QDomEntity.nodeType()'''
        return QDomNode.NodeType()
    def notationName(self):
        '''str QDomEntity.notationName()'''
        return str()
    def systemId(self):
        '''str QDomEntity.systemId()'''
        return str()
    def publicId(self):
        '''str QDomEntity.publicId()'''
        return str()


class QDomEntityReference(QDomNode):
    """"""
    def __init__(self):
        '''void QDomEntityReference.__init__()'''
    def __init__(self, x):
        '''void QDomEntityReference.__init__(QDomEntityReference x)'''
    def nodeType(self):
        '''QDomNode.NodeType QDomEntityReference.nodeType()'''
        return QDomNode.NodeType()


class QDomProcessingInstruction(QDomNode):
    """"""
    def __init__(self):
        '''void QDomProcessingInstruction.__init__()'''
    def __init__(self, x):
        '''void QDomProcessingInstruction.__init__(QDomProcessingInstruction x)'''
    def nodeType(self):
        '''QDomNode.NodeType QDomProcessingInstruction.nodeType()'''
        return QDomNode.NodeType()
    def setData(self, d):
        '''void QDomProcessingInstruction.setData(str d)'''
    def data(self):
        '''str QDomProcessingInstruction.data()'''
        return str()
    def target(self):
        '''str QDomProcessingInstruction.target()'''
        return str()





class pyqtSignal():
 def connect(self, targetSignal): pass
 def emit(self, *args): pass
from QtCore import *

from QtWidgets import *

import datetime

class QMacPasteboardMime():
    """"""
    # Enum QMacPasteboardMime.QMacPasteboardMimeType
    MIME_DND = 0
    MIME_CLIP = 0
    MIME_QT_CONVERTOR = 0
    MIME_QT3_CONVERTOR = 0
    MIME_ALL = 0

    def __init__(self, t):
        '''void QMacPasteboardMime.__init__(int t)'''
    def __init__(self):
        '''QMacPasteboardMime QMacPasteboardMime.__init__()'''
        return QMacPasteboardMime()
    def count(self, mimeData):
        '''int QMacPasteboardMime.count(QMimeData mimeData)'''
        return int()
    def convertFromMime(self, mime, data, flav):
        '''abstract list-of-QByteArray QMacPasteboardMime.convertFromMime(str mime, QVariant data, str flav)'''
        return [QByteArray()]
    def convertToMime(self, mime, data, flav):
        '''abstract QVariant QMacPasteboardMime.convertToMime(str mime, list-of-QByteArray data, str flav)'''
        return QVariant()
    def flavorFor(self, mime):
        '''abstract str QMacPasteboardMime.flavorFor(str mime)'''
        return str()
    def mimeFor(self, flav):
        '''abstract str QMacPasteboardMime.mimeFor(str flav)'''
        return str()
    def canConvert(self, mime, flav):
        '''abstract bool QMacPasteboardMime.canConvert(str mime, str flav)'''
        return bool()
    def convertorName(self):
        '''abstract str QMacPasteboardMime.convertorName()'''
        return str()


class QMacToolBar(QObject):
    """"""
    def __init__(self, parent = None):
        '''void QMacToolBar.__init__(QObject parent = None)'''
    def __init__(self, identifier, parent = None):
        '''void QMacToolBar.__init__(str identifier, QObject parent = None)'''
    def nativeToolbar(self):
        '''NSToolbar QMacToolBar.nativeToolbar()'''
        return NSToolbar()
    def detachFromWindow(self):
        '''void QMacToolBar.detachFromWindow()'''
    def attachToWindow(self, window):
        '''void QMacToolBar.attachToWindow(QWindow window)'''
    def allowedItems(self):
        '''list-of-QMacToolBarItem QMacToolBar.allowedItems()'''
        return [QMacToolBarItem()]
    def setAllowedItems(self, allowedItems):
        '''void QMacToolBar.setAllowedItems(list-of-QMacToolBarItem allowedItems)'''
    def items(self):
        '''list-of-QMacToolBarItem QMacToolBar.items()'''
        return [QMacToolBarItem()]
    def setItems(self, items):
        '''void QMacToolBar.setItems(list-of-QMacToolBarItem items)'''
    def addSeparator(self):
        '''void QMacToolBar.addSeparator()'''
    def addAllowedItem(self, icon, text):
        '''QMacToolBarItem QMacToolBar.addAllowedItem(QIcon icon, str text)'''
        return QMacToolBarItem()
    def addItem(self, icon, text):
        '''QMacToolBarItem QMacToolBar.addItem(QIcon icon, str text)'''
        return QMacToolBarItem()


class QMacToolBarItem(QObject):
    """"""
    # Enum QMacToolBarItem.StandardItem
    NoStandardItem = 0
    Space = 0
    FlexibleSpace = 0

    def __init__(self, parent = None):
        '''void QMacToolBarItem.__init__(QObject parent = None)'''
    activated = pyqtSignal() # void activated() - signal
    def nativeToolBarItem(self):
        '''NSToolbarItem QMacToolBarItem.nativeToolBarItem()'''
        return NSToolbarItem()
    def setIcon(self, icon):
        '''void QMacToolBarItem.setIcon(QIcon icon)'''
    def icon(self):
        '''QIcon QMacToolBarItem.icon()'''
        return QIcon()
    def setText(self, text):
        '''void QMacToolBarItem.setText(str text)'''
    def text(self):
        '''str QMacToolBarItem.text()'''
        return str()
    def setStandardItem(self, standardItem):
        '''void QMacToolBarItem.setStandardItem(QMacToolBarItem.StandardItem standardItem)'''
    def standardItem(self):
        '''QMacToolBarItem.StandardItem QMacToolBarItem.standardItem()'''
        return QMacToolBarItem.StandardItem()
    def setSelectable(self, selectable):
        '''void QMacToolBarItem.setSelectable(bool selectable)'''
    def selectable(self):
        '''bool QMacToolBarItem.selectable()'''
        return bool()


def qRegisterDraggedTypes(types):
    '''static void qRegisterDraggedTypes(list-of-str types)'''


